# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gobgp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bgobgp.proto\x12\x05\x61pipb\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"0\n\x0fStartBgpRequest\x12\x1d\n\x06global\x18\x01 \x01(\x0b\x32\r.apipb.Global\"\x10\n\x0eStopBgpRequest\"\x0f\n\rGetBgpRequest\"/\n\x0eGetBgpResponse\x12\x1d\n\x06global\x18\x01 \x01(\x0b\x32\r.apipb.Global\"\xe4\x02\n\x11WatchEventRequest\x12+\n\x04peer\x18\x01 \x01(\x0b\x32\x1d.apipb.WatchEventRequest.Peer\x12-\n\x05table\x18\x02 \x01(\x0b\x32\x1e.apipb.WatchEventRequest.Table\x1a\x06\n\x04Peer\x1a\xea\x01\n\x05Table\x12\x36\n\x07\x66ilters\x18\x01 \x03(\x0b\x32%.apipb.WatchEventRequest.Table.Filter\x1a\xa8\x01\n\x06\x46ilter\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.apipb.WatchEventRequest.Table.Filter.Type\x12\x0c\n\x04init\x18\x02 \x01(\x08\x12\x14\n\x0cpeer_address\x18\x03 \x01(\t\x12\x12\n\npeer_group\x18\x04 \x01(\t\",\n\x04Type\x12\x08\n\x04\x42\x45ST\x10\x00\x12\t\n\x05\x41\x44JIN\x10\x01\x12\x0f\n\x0bPOST_POLICY\x10\x02\"\xcf\x02\n\x12WatchEventResponse\x12\x33\n\x04peer\x18\x02 \x01(\x0b\x32#.apipb.WatchEventResponse.PeerEventH\x00\x12\x35\n\x05table\x18\x03 \x01(\x0b\x32$.apipb.WatchEventResponse.TableEventH\x00\x1a\x99\x01\n\tPeerEvent\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.apipb.WatchEventResponse.PeerEvent.Type\x12\x19\n\x04peer\x18\x02 \x01(\x0b\x32\x0b.apipb.Peer\"9\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04INIT\x10\x01\x12\x0f\n\x0b\x45ND_OF_INIT\x10\x02\x12\t\n\x05STATE\x10\x03\x1a(\n\nTableEvent\x12\x1a\n\x05paths\x18\x02 \x03(\x0b\x32\x0b.apipb.PathB\x07\n\x05\x65vent\"+\n\x0e\x41\x64\x64PeerRequest\x12\x19\n\x04peer\x18\x01 \x01(\x0b\x32\x0b.apipb.Peer\"7\n\x11\x44\x65letePeerRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tinterface\x18\x02 \x01(\t\"<\n\x0fListPeerRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x18\n\x10\x65nableAdvertised\x18\x02 \x01(\x08\"-\n\x10ListPeerResponse\x12\x19\n\x04peer\x18\x01 \x01(\x0b\x32\x0b.apipb.Peer\"H\n\x11UpdatePeerRequest\x12\x19\n\x04peer\x18\x01 \x01(\x0b\x32\x0b.apipb.Peer\x12\x18\n\x10\x64o_soft_reset_in\x18\x02 \x01(\x08\"1\n\x12UpdatePeerResponse\x12\x1b\n\x13needs_soft_reset_in\x18\x01 \x01(\x08\"\xb8\x01\n\x10ResetPeerRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x15\n\rcommunication\x18\x02 \x01(\t\x12\x0c\n\x04soft\x18\x03 \x01(\x08\x12=\n\tdirection\x18\x04 \x01(\x0e\x32*.apipb.ResetPeerRequest.SoftResetDirection\"/\n\x12SoftResetDirection\x12\x06\n\x02IN\x10\x00\x12\x07\n\x03OUT\x10\x01\x12\x08\n\x04\x42OTH\x10\x02\"=\n\x13ShutdownPeerRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x15\n\rcommunication\x18\x02 \x01(\t\"$\n\x11\x45nablePeerRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"<\n\x12\x44isablePeerRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x15\n\rcommunication\x18\x02 \x01(\t\";\n\x13\x41\x64\x64PeerGroupRequest\x12$\n\npeer_group\x18\x01 \x01(\x0b\x32\x10.apipb.PeerGroup\"&\n\x16\x44\x65letePeerGroupRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"X\n\x16UpdatePeerGroupRequest\x12$\n\npeer_group\x18\x01 \x01(\x0b\x32\x10.apipb.PeerGroup\x12\x18\n\x10\x64o_soft_reset_in\x18\x02 \x01(\x08\"6\n\x17UpdatePeerGroupResponse\x12\x1b\n\x13needs_soft_reset_in\x18\x01 \x01(\x08\"/\n\x14ListPeerGroupRequest\x12\x17\n\x0fpeer_group_name\x18\x01 \x01(\t\"=\n\x15ListPeerGroupResponse\x12$\n\npeer_group\x18\x01 \x01(\x0b\x32\x10.apipb.PeerGroup\"M\n\x19\x41\x64\x64\x44ynamicNeighborRequest\x12\x30\n\x10\x64ynamic_neighbor\x18\x01 \x01(\x0b\x32\x16.apipb.DynamicNeighbor\"B\n\x1c\x44\x65leteDynamicNeighborRequest\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x12\n\npeer_group\x18\x02 \x01(\t\"0\n\x1aListDynamicNeighborRequest\x12\x12\n\npeer_group\x18\x01 \x01(\t\"O\n\x1bListDynamicNeighborResponse\x12\x30\n\x10\x64ynamic_neighbor\x18\x01 \x01(\x0b\x32\x16.apipb.DynamicNeighbor\"a\n\x0e\x41\x64\x64PathRequest\x12$\n\ntable_type\x18\x01 \x01(\x0e\x32\x10.apipb.TableType\x12\x0e\n\x06vrf_id\x18\x02 \x01(\t\x12\x19\n\x04path\x18\x03 \x01(\x0b\x32\x0b.apipb.Path\"\x1f\n\x0f\x41\x64\x64PathResponse\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"\x91\x01\n\x11\x44\x65letePathRequest\x12$\n\ntable_type\x18\x01 \x01(\x0e\x32\x10.apipb.TableType\x12\x0e\n\x06vrf_id\x18\x02 \x01(\t\x12\x1d\n\x06\x66\x61mily\x18\x03 \x01(\x0b\x32\r.apipb.Family\x12\x19\n\x04path\x18\x04 \x01(\x0b\x32\x0b.apipb.Path\x12\x0c\n\x04uuid\x18\x05 \x01(\x0c\"\x88\x01\n\x11TableLookupPrefix\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12+\n\x04type\x18\x02 \x01(\x0e\x32\x1d.apipb.TableLookupPrefix.Type\x12\n\n\x02rd\x18\x03 \x01(\t\"*\n\x04Type\x12\t\n\x05\x45XACT\x10\x00\x12\n\n\x06LONGER\x10\x01\x12\x0b\n\x07SHORTER\x10\x02\"\xec\x02\n\x0fListPathRequest\x12$\n\ntable_type\x18\x01 \x01(\x0e\x32\x10.apipb.TableType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x06\x66\x61mily\x18\x03 \x01(\x0b\x32\r.apipb.Family\x12*\n\x08prefixes\x18\x04 \x03(\x0b\x32\x18.apipb.TableLookupPrefix\x12\x32\n\tsort_type\x18\x05 \x01(\x0e\x32\x1f.apipb.ListPathRequest.SortType\x12\x17\n\x0f\x65nable_filtered\x18\x06 \x01(\x08\x12\x1a\n\x12\x65nable_nlri_binary\x18\x07 \x01(\x08\x12\x1f\n\x17\x65nable_attribute_binary\x18\x08 \x01(\x08\x12\x1a\n\x12\x65nable_only_binary\x18\t \x01(\x08\x12\x12\n\nbatch_size\x18\n \x01(\x04\" \n\x08SortType\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06PREFIX\x10\x01\";\n\x10ListPathResponse\x12\'\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32\x12.apipb.Destination\"h\n\x14\x41\x64\x64PathStreamRequest\x12$\n\ntable_type\x18\x01 \x01(\x0e\x32\x10.apipb.TableType\x12\x0e\n\x06vrf_id\x18\x02 \x01(\t\x12\x1a\n\x05paths\x18\x03 \x03(\x0b\x32\x0b.apipb.Path\"d\n\x0fGetTableRequest\x12$\n\ntable_type\x18\x01 \x01(\x0e\x32\x10.apipb.TableType\x12\x1d\n\x06\x66\x61mily\x18\x02 \x01(\x0b\x32\r.apipb.Family\x12\x0c\n\x04name\x18\x03 \x01(\t\"S\n\x10GetTableResponse\x12\x17\n\x0fnum_destination\x18\x01 \x01(\x04\x12\x10\n\x08num_path\x18\x02 \x01(\x04\x12\x14\n\x0cnum_accepted\x18\x03 \x01(\x04\"(\n\rAddVrfRequest\x12\x17\n\x03vrf\x18\x01 \x01(\x0b\x32\n.apipb.Vrf\" \n\x10\x44\x65leteVrfRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1e\n\x0eListVrfRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"*\n\x0fListVrfResponse\x12\x17\n\x03vrf\x18\x01 \x01(\x0b\x32\n.apipb.Vrf\"T\n\x10\x41\x64\x64PolicyRequest\x12\x1d\n\x06policy\x18\x01 \x01(\x0b\x32\r.apipb.Policy\x12!\n\x19refer_existing_statements\x18\x02 \x01(\x08\"^\n\x13\x44\x65letePolicyRequest\x12\x1d\n\x06policy\x18\x01 \x01(\x0b\x32\r.apipb.Policy\x12\x1b\n\x13preserve_statements\x18\x02 \x01(\x08\x12\x0b\n\x03\x61ll\x18\x03 \x01(\x08\"!\n\x11ListPolicyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"3\n\x12ListPolicyResponse\x12\x1d\n\x06policy\x18\x01 \x01(\x0b\x32\r.apipb.Policy\"\x8c\x01\n\x12SetPoliciesRequest\x12\'\n\x0c\x64\x65\x66ined_sets\x18\x01 \x03(\x0b\x32\x11.apipb.DefinedSet\x12\x1f\n\x08policies\x18\x02 \x03(\x0b\x32\r.apipb.Policy\x12,\n\x0b\x61ssignments\x18\x03 \x03(\x0b\x32\x17.apipb.PolicyAssignment\">\n\x14\x41\x64\x64\x44\x65\x66inedSetRequest\x12&\n\x0b\x64\x65\x66ined_set\x18\x01 \x01(\x0b\x32\x11.apipb.DefinedSet\"N\n\x17\x44\x65leteDefinedSetRequest\x12&\n\x0b\x64\x65\x66ined_set\x18\x01 \x01(\x0b\x32\x11.apipb.DefinedSet\x12\x0b\n\x03\x61ll\x18\x02 \x01(\x08\"O\n\x15ListDefinedSetRequest\x12(\n\x0c\x64\x65\x66ined_type\x18\x01 \x01(\x0e\x32\x12.apipb.DefinedType\x12\x0c\n\x04name\x18\x02 \x01(\t\"@\n\x16ListDefinedSetResponse\x12&\n\x0b\x64\x65\x66ined_set\x18\x01 \x01(\x0b\x32\x11.apipb.DefinedSet\":\n\x13\x41\x64\x64StatementRequest\x12#\n\tstatement\x18\x01 \x01(\x0b\x32\x10.apipb.Statement\"J\n\x16\x44\x65leteStatementRequest\x12#\n\tstatement\x18\x01 \x01(\x0b\x32\x10.apipb.Statement\x12\x0b\n\x03\x61ll\x18\x02 \x01(\x08\"$\n\x14ListStatementRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"<\n\x15ListStatementResponse\x12#\n\tstatement\x18\x01 \x01(\x0b\x32\x10.apipb.Statement\"I\n\x1a\x41\x64\x64PolicyAssignmentRequest\x12+\n\nassignment\x18\x01 \x01(\x0b\x32\x17.apipb.PolicyAssignment\"Y\n\x1d\x44\x65letePolicyAssignmentRequest\x12+\n\nassignment\x18\x01 \x01(\x0b\x32\x17.apipb.PolicyAssignment\x12\x0b\n\x03\x61ll\x18\x02 \x01(\x08\"V\n\x1bListPolicyAssignmentRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\tdirection\x18\x02 \x01(\x0e\x32\x16.apipb.PolicyDirection\"K\n\x1cListPolicyAssignmentResponse\x12+\n\nassignment\x18\x01 \x01(\x0b\x32\x17.apipb.PolicyAssignment\"I\n\x1aSetPolicyAssignmentRequest\x12+\n\nassignment\x18\x01 \x01(\x0b\x32\x17.apipb.PolicyAssignment\"A\n\x0e\x41\x64\x64RpkiRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x10\n\x08lifetime\x18\x03 \x01(\x03\"2\n\x11\x44\x65leteRpkiRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\"0\n\x0fListRpkiRequest\x12\x1d\n\x06\x66\x61mily\x18\x01 \x01(\x0b\x32\r.apipb.Family\"/\n\x10ListRpkiResponse\x12\x1b\n\x06server\x18\x01 \x01(\x0b\x32\x0b.apipb.Rpki\"2\n\x11\x45nableRpkiRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\"3\n\x12\x44isableRpkiRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\"?\n\x10ResetRpkiRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0c\n\x04soft\x18\x03 \x01(\x08\"5\n\x14ListRpkiTableRequest\x12\x1d\n\x06\x66\x61mily\x18\x01 \x01(\x0b\x32\r.apipb.Family\"0\n\x15ListRpkiTableResponse\x12\x17\n\x03roa\x18\x01 \x01(\x0b\x32\n.apipb.Roa\"\xbc\x01\n\x12\x45nableZebraRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0broute_types\x18\x02 \x03(\t\x12\x0f\n\x07version\x18\x03 \x01(\r\x12\x1e\n\x16nexthop_trigger_enable\x18\x04 \x01(\x08\x12\x1d\n\x15nexthop_trigger_delay\x18\x05 \x01(\r\x12\x1d\n\x15mpls_label_range_size\x18\x06 \x01(\r\x12\x15\n\rsoftware_name\x18\x07 \x01(\t\"\xaa\x01\n\x10\x45nableMrtRequest\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .apipb.EnableMrtRequest.DumpType\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x15\n\rdump_interval\x18\x03 \x01(\x04\x12\x19\n\x11rotation_interval\x18\x04 \x01(\x04\"\"\n\x08\x44umpType\x12\x0b\n\x07UPDATES\x10\x00\x12\t\n\x05TABLE\x10\x01\"%\n\x11\x44isableMrtRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\"\xe8\x01\n\rAddBmpRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x35\n\x06policy\x18\x03 \x01(\x0e\x32%.apipb.AddBmpRequest.MonitoringPolicy\x12\x19\n\x11StatisticsTimeout\x18\x04 \x01(\x05\x12\x0f\n\x07SysName\x18\x05 \x01(\t\x12\x10\n\x08SysDescr\x18\x06 \x01(\t\"C\n\x10MonitoringPolicy\x12\x07\n\x03PRE\x10\x00\x12\x08\n\x04POST\x10\x01\x12\x08\n\x04\x42OTH\x10\x02\x12\t\n\x05LOCAL\x10\x03\x12\x07\n\x03\x41LL\x10\x04\"1\n\x10\x44\x65leteBmpRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\"\x10\n\x0eListBmpRequest\"\xcc\x02\n\x0fListBmpResponse\x12\x32\n\x07station\x18\x01 \x01(\x0b\x32!.apipb.ListBmpResponse.BmpStation\x1a\x84\x02\n\nBmpStation\x12\x34\n\x04\x63onf\x18\x01 \x01(\x0b\x32&.apipb.ListBmpResponse.BmpStation.Conf\x12\x36\n\x05state\x18\x02 \x01(\x0b\x32\'.apipb.ListBmpResponse.BmpStation.State\x1a%\n\x04\x43onf\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x1a\x61\n\x05State\x12*\n\x06uptime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64owntime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x86\x04\n\x06\x46\x61mily\x12\x1e\n\x03\x61\x66i\x18\x01 \x01(\x0e\x32\x11.apipb.Family.Afi\x12 \n\x04safi\x18\x02 \x01(\x0e\x32\x12.apipb.Family.Safi\"^\n\x03\x41\x66i\x12\x0f\n\x0b\x41\x46I_UNKNOWN\x10\x00\x12\n\n\x06\x41\x46I_IP\x10\x01\x12\x0b\n\x07\x41\x46I_IP6\x10\x02\x12\r\n\tAFI_L2VPN\x10\x19\x12\x0c\n\x06\x41\x46I_LS\x10\x84\x80\x01\x12\x10\n\nAFI_OPAQUE\x10\x8d\x80\x01\"\xd9\x02\n\x04Safi\x12\x10\n\x0cSAFI_UNKNOWN\x10\x00\x12\x10\n\x0cSAFI_UNICAST\x10\x01\x12\x12\n\x0eSAFI_MULTICAST\x10\x02\x12\x13\n\x0fSAFI_MPLS_LABEL\x10\x04\x12\x16\n\x12SAFI_ENCAPSULATION\x10\x07\x12\r\n\tSAFI_VPLS\x10\x41\x12\r\n\tSAFI_EVPN\x10\x46\x12\x0b\n\x07SAFI_LS\x10G\x12\x12\n\x0eSAFI_SR_POLICY\x10I\x12\x0c\n\x08SAFI_MUP\x10U\x12\x12\n\rSAFI_MPLS_VPN\x10\x80\x01\x12\x1c\n\x17SAFI_MPLS_VPN_MULTICAST\x10\x81\x01\x12\"\n\x1dSAFI_ROUTE_TARGET_CONSTRAINTS\x10\x84\x01\x12\x1b\n\x16SAFI_FLOW_SPEC_UNICAST\x10\x85\x01\x12\x17\n\x12SAFI_FLOW_SPEC_VPN\x10\x86\x01\x12\x13\n\x0eSAFI_KEY_VALUE\x10\xf1\x01\"\xd4\x02\n\nValidation\x12&\n\x05state\x18\x01 \x01(\x0e\x32\x17.apipb.Validation.State\x12(\n\x06reason\x18\x02 \x01(\x0e\x32\x18.apipb.Validation.Reason\x12\x1b\n\x07matched\x18\x03 \x03(\x0b\x32\n.apipb.Roa\x12!\n\runmatched_asn\x18\x04 \x03(\x0b\x32\n.apipb.Roa\x12$\n\x10unmatched_length\x18\x05 \x03(\x0b\x32\n.apipb.Roa\"P\n\x05State\x12\x0e\n\nSTATE_NONE\x10\x00\x12\x13\n\x0fSTATE_NOT_FOUND\x10\x01\x12\x0f\n\x0bSTATE_VALID\x10\x02\x12\x11\n\rSTATE_INVALID\x10\x03\"<\n\x06Reason\x12\x0f\n\x0bREASON_NONE\x10\x00\x12\x0e\n\nREASON_ASN\x10\x01\x12\x11\n\rREASON_LENGTH\x10\x02\"\xfb\x03\n\x04Path\x12\"\n\x04nlri\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12$\n\x06pattrs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12\'\n\x03\x61ge\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x62\x65st\x18\x04 \x01(\x08\x12\x13\n\x0bis_withdraw\x18\x05 \x01(\x08\x12%\n\nvalidation\x18\x07 \x01(\x0b\x32\x11.apipb.Validation\x12\x1c\n\x14no_implicit_withdraw\x18\x08 \x01(\x08\x12\x1d\n\x06\x66\x61mily\x18\t \x01(\x0b\x32\r.apipb.Family\x12\x12\n\nsource_asn\x18\n \x01(\r\x12\x11\n\tsource_id\x18\x0b \x01(\t\x12\x10\n\x08\x66iltered\x18\x0c \x01(\x08\x12\r\n\x05stale\x18\r \x01(\x08\x12\x18\n\x10is_from_external\x18\x0e \x01(\x08\x12\x13\n\x0bneighbor_ip\x18\x0f \x01(\t\x12\x0c\n\x04uuid\x18\x10 \x01(\x0c\x12\x1a\n\x12is_nexthop_invalid\x18\x11 \x01(\x08\x12\x12\n\nidentifier\x18\x12 \x01(\r\x12\x18\n\x10local_identifier\x18\x13 \x01(\r\x12\x13\n\x0bnlri_binary\x18\x14 \x01(\x0c\x12\x15\n\rpattrs_binary\x18\x15 \x03(\x0c\"9\n\x0b\x44\x65stination\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x1a\n\x05paths\x18\x02 \x03(\x0b\x32\x0b.apipb.Path\"\xb9\x03\n\x04Peer\x12(\n\x0c\x61pply_policy\x18\x01 \x01(\x0b\x32\x12.apipb.ApplyPolicy\x12\x1d\n\x04\x63onf\x18\x02 \x01(\x0b\x32\x0f.apipb.PeerConf\x12*\n\rebgp_multihop\x18\x03 \x01(\x0b\x32\x13.apipb.EbgpMultihop\x12.\n\x0froute_reflector\x18\x04 \x01(\x0b\x32\x15.apipb.RouteReflector\x12\x1f\n\x05state\x18\x05 \x01(\x0b\x32\x10.apipb.PeerState\x12\x1d\n\x06timers\x18\x06 \x01(\x0b\x32\r.apipb.Timers\x12#\n\ttransport\x18\x07 \x01(\x0b\x32\x10.apipb.Transport\x12(\n\x0croute_server\x18\x08 \x01(\x0b\x32\x12.apipb.RouteServer\x12\x30\n\x10graceful_restart\x18\t \x01(\x0b\x32\x16.apipb.GracefulRestart\x12!\n\tafi_safis\x18\n \x03(\x0b\x32\x0e.apipb.AfiSafi\x12(\n\x0cttl_security\x18\x0b \x01(\x0b\x32\x12.apipb.TtlSecurity\"\xc7\x03\n\tPeerGroup\x12(\n\x0c\x61pply_policy\x18\x01 \x01(\x0b\x32\x12.apipb.ApplyPolicy\x12\"\n\x04\x63onf\x18\x02 \x01(\x0b\x32\x14.apipb.PeerGroupConf\x12*\n\rebgp_multihop\x18\x03 \x01(\x0b\x32\x13.apipb.EbgpMultihop\x12.\n\x0froute_reflector\x18\x04 \x01(\x0b\x32\x15.apipb.RouteReflector\x12#\n\x04info\x18\x05 \x01(\x0b\x32\x15.apipb.PeerGroupState\x12\x1d\n\x06timers\x18\x06 \x01(\x0b\x32\r.apipb.Timers\x12#\n\ttransport\x18\x07 \x01(\x0b\x32\x10.apipb.Transport\x12(\n\x0croute_server\x18\x08 \x01(\x0b\x32\x12.apipb.RouteServer\x12\x30\n\x10graceful_restart\x18\t \x01(\x0b\x32\x16.apipb.GracefulRestart\x12!\n\tafi_safis\x18\n \x03(\x0b\x32\x0e.apipb.AfiSafi\x12(\n\x0cttl_security\x18\x0b \x01(\x0b\x32\x12.apipb.TtlSecurity\"5\n\x0f\x44ynamicNeighbor\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x12\n\npeer_group\x18\x02 \x01(\t\"\x99\x01\n\x0b\x41pplyPolicy\x12*\n\tin_policy\x18\x01 \x01(\x0b\x32\x17.apipb.PolicyAssignment\x12.\n\rexport_policy\x18\x02 \x01(\x0b\x32\x17.apipb.PolicyAssignment\x12.\n\rimport_policy\x18\x03 \x01(\x0b\x32\x17.apipb.PolicyAssignment\"b\n\x0bPrefixLimit\x12\x1d\n\x06\x66\x61mily\x18\x01 \x01(\x0b\x32\r.apipb.Family\x12\x14\n\x0cmax_prefixes\x18\x02 \x01(\r\x12\x1e\n\x16shutdown_threshold_pct\x18\x03 \x01(\r\"\x97\x03\n\x08PeerConf\x12\x15\n\rauth_password\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tlocal_asn\x18\x03 \x01(\r\x12\x18\n\x10neighbor_address\x18\x04 \x01(\t\x12\x10\n\x08peer_asn\x18\x05 \x01(\r\x12\x12\n\npeer_group\x18\x06 \x01(\t\x12\x1d\n\x04type\x18\x07 \x01(\x0e\x32\x0f.apipb.PeerType\x12,\n\x0eremove_private\x18\x08 \x01(\x0e\x32\x14.apipb.RemovePrivate\x12\x1a\n\x12route_flap_damping\x18\t \x01(\x08\x12\x16\n\x0esend_community\x18\n \x01(\r\x12\x1a\n\x12neighbor_interface\x18\x0b \x01(\t\x12\x0b\n\x03vrf\x18\x0c \x01(\t\x12\x15\n\rallow_own_asn\x18\r \x01(\r\x12\x18\n\x10replace_peer_asn\x18\x0e \x01(\x08\x12\x12\n\nadmin_down\x18\x0f \x01(\x08\x12\x1d\n\x15send_software_version\x18\x10 \x01(\x08\"\xfa\x01\n\rPeerGroupConf\x12\x15\n\rauth_password\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tlocal_asn\x18\x03 \x01(\r\x12\x10\n\x08peer_asn\x18\x04 \x01(\r\x12\x17\n\x0fpeer_group_name\x18\x05 \x01(\t\x12\x1d\n\x04type\x18\x06 \x01(\x0e\x32\x0f.apipb.PeerType\x12,\n\x0eremove_private\x18\x07 \x01(\x0e\x32\x14.apipb.RemovePrivate\x12\x1a\n\x12route_flap_damping\x18\x08 \x01(\x08\x12\x16\n\x0esend_community\x18\t \x01(\r\"\xa8\x02\n\x0ePeerGroupState\x12\x15\n\rauth_password\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tlocal_asn\x18\x03 \x01(\r\x12\x10\n\x08peer_asn\x18\x04 \x01(\r\x12\x17\n\x0fpeer_group_name\x18\x05 \x01(\t\x12\x1d\n\x04type\x18\x06 \x01(\x0e\x32\x0f.apipb.PeerType\x12,\n\x0eremove_private\x18\x07 \x01(\x0e\x32\x14.apipb.RemovePrivate\x12\x1a\n\x12route_flap_damping\x18\x08 \x01(\x08\x12\x16\n\x0esend_community\x18\t \x01(\r\x12\x13\n\x0btotal_paths\x18\n \x01(\r\x12\x16\n\x0etotal_prefixes\x18\x0b \x01(\r\"/\n\x0bTtlSecurity\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07ttl_min\x18\x02 \x01(\r\"5\n\x0c\x45\x62gpMultihop\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0cmultihop_ttl\x18\x02 \x01(\r\"T\n\x0eRouteReflector\x12\x1e\n\x16route_reflector_client\x18\x01 \x01(\x08\x12\"\n\x1aroute_reflector_cluster_id\x18\x02 \x01(\t\"\xd5\x05\n\tPeerState\x12\x15\n\rauth_password\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tlocal_asn\x18\x03 \x01(\r\x12!\n\x08messages\x18\x04 \x01(\x0b\x32\x0f.apipb.Messages\x12\x18\n\x10neighbor_address\x18\x05 \x01(\t\x12\x10\n\x08peer_asn\x18\x06 \x01(\r\x12\x12\n\npeer_group\x18\x07 \x01(\t\x12\x1d\n\x04type\x18\x08 \x01(\x0e\x32\x0f.apipb.PeerType\x12\x1d\n\x06queues\x18\t \x01(\x0b\x32\r.apipb.Queues\x12,\n\x0eremove_private\x18\n \x01(\x0e\x32\x14.apipb.RemovePrivate\x12\x1a\n\x12route_flap_damping\x18\x0b \x01(\x08\x12\x16\n\x0esend_community\x18\x0c \x01(\r\x12\x34\n\rsession_state\x18\r \x01(\x0e\x32\x1d.apipb.PeerState.SessionState\x12\x30\n\x0b\x61\x64min_state\x18\x0f \x01(\x0e\x32\x1b.apipb.PeerState.AdminState\x12\r\n\x05out_q\x18\x10 \x01(\r\x12\r\n\x05\x66lops\x18\x11 \x01(\r\x12(\n\nremote_cap\x18\x12 \x03(\x0b\x32\x14.google.protobuf.Any\x12\'\n\tlocal_cap\x18\x13 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\trouter_id\x18\x14 \x01(\t\"n\n\x0cSessionState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04IDLE\x10\x01\x12\x0b\n\x07\x43ONNECT\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08OPENSENT\x10\x04\x12\x0f\n\x0bOPENCONFIRM\x10\x05\x12\x0f\n\x0b\x45STABLISHED\x10\x06\"*\n\nAdminState\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\n\n\x06PFX_CT\x10\x02\"J\n\x08Messages\x12 \n\x08received\x18\x01 \x01(\x0b\x32\x0e.apipb.Message\x12\x1c\n\x04sent\x18\x02 \x01(\x0b\x32\x0e.apipb.Message\"\xb5\x01\n\x07Message\x12\x14\n\x0cnotification\x18\x01 \x01(\x04\x12\x0e\n\x06update\x18\x02 \x01(\x04\x12\x0c\n\x04open\x18\x03 \x01(\x04\x12\x11\n\tkeepalive\x18\x04 \x01(\x04\x12\x0f\n\x07refresh\x18\x05 \x01(\x04\x12\x11\n\tdiscarded\x18\x06 \x01(\x04\x12\r\n\x05total\x18\x07 \x01(\x04\x12\x17\n\x0fwithdraw_update\x18\x08 \x01(\x04\x12\x17\n\x0fwithdraw_prefix\x18\t \x01(\x04\"\'\n\x06Queues\x12\r\n\x05input\x18\x01 \x01(\r\x12\x0e\n\x06output\x18\x02 \x01(\r\"P\n\x06Timers\x12#\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x13.apipb.TimersConfig\x12!\n\x05state\x18\x02 \x01(\x0b\x32\x12.apipb.TimersState\"\xa0\x01\n\x0cTimersConfig\x12\x15\n\rconnect_retry\x18\x01 \x01(\x04\x12\x11\n\thold_time\x18\x02 \x01(\x04\x12\x1a\n\x12keepalive_interval\x18\x03 \x01(\x04\x12&\n\x1eminimum_advertisement_interval\x18\x04 \x01(\x04\x12\"\n\x1aidle_hold_time_after_reset\x18\x05 \x01(\x04\"\xf3\x01\n\x0bTimersState\x12\x15\n\rconnect_retry\x18\x01 \x01(\x04\x12\x11\n\thold_time\x18\x02 \x01(\x04\x12\x1a\n\x12keepalive_interval\x18\x03 \x01(\x04\x12&\n\x1eminimum_advertisement_interval\x18\x04 \x01(\x04\x12\x1c\n\x14negotiated_hold_time\x18\x05 \x01(\x04\x12*\n\x06uptime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64owntime\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb9\x01\n\tTransport\x12\x15\n\rlocal_address\x18\x01 \x01(\t\x12\x12\n\nlocal_port\x18\x02 \x01(\r\x12\x15\n\rmtu_discovery\x18\x03 \x01(\x08\x12\x14\n\x0cpassive_mode\x18\x04 \x01(\x08\x12\x16\n\x0eremote_address\x18\x05 \x01(\t\x12\x13\n\x0bremote_port\x18\x06 \x01(\r\x12\x0f\n\x07tcp_mss\x18\x07 \x01(\r\x12\x16\n\x0e\x62ind_interface\x18\x08 \x01(\t\"C\n\x0bRouteServer\x12\x1b\n\x13route_server_client\x18\x01 \x01(\x08\x12\x17\n\x0fsecondary_route\x18\x02 \x01(\x08\"\x94\x02\n\x0fGracefulRestart\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0crestart_time\x18\x02 \x01(\r\x12\x13\n\x0bhelper_only\x18\x03 \x01(\x08\x12\x15\n\rdeferral_time\x18\x04 \x01(\r\x12\x1c\n\x14notification_enabled\x18\x05 \x01(\x08\x12\x19\n\x11longlived_enabled\x18\x06 \x01(\x08\x12\x19\n\x11stale_routes_time\x18\x07 \x01(\r\x12\x19\n\x11peer_restart_time\x18\x08 \x01(\r\x12\x17\n\x0fpeer_restarting\x18\t \x01(\x08\x12\x18\n\x10local_restarting\x18\n \x01(\x08\x12\x0c\n\x04mode\x18\x0b \x01(\t\"*\n\x17MpGracefulRestartConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\x85\x01\n\x16MpGracefulRestartState\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x10\n\x08received\x18\x02 \x01(\x08\x12\x12\n\nadvertised\x18\x03 \x01(\x08\x12\x1b\n\x13\x65nd_of_rib_received\x18\x04 \x01(\x08\x12\x17\n\x0f\x65nd_of_rib_sent\x18\x05 \x01(\x08\"q\n\x11MpGracefulRestart\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1e.apipb.MpGracefulRestartConfig\x12,\n\x05state\x18\x02 \x01(\x0b\x32\x1d.apipb.MpGracefulRestartState\"?\n\rAfiSafiConfig\x12\x1d\n\x06\x66\x61mily\x18\x01 \x01(\x0b\x32\r.apipb.Family\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"v\n\x0c\x41\x66iSafiState\x12\x1d\n\x06\x66\x61mily\x18\x01 \x01(\x0b\x32\r.apipb.Family\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x10\n\x08received\x18\x03 \x01(\x04\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x04 \x01(\x04\x12\x12\n\nadvertised\x18\x05 \x01(\x04\"\xfd\x01\n\x1bRouteSelectionOptionsConfig\x12\x1a\n\x12\x61lways_compare_med\x18\x01 \x01(\x08\x12\x1d\n\x15ignore_as_path_length\x18\x02 \x01(\x08\x12\"\n\x1a\x65xternal_compare_router_id\x18\x03 \x01(\x08\x12!\n\x19\x61\x64vertise_inactive_routes\x18\x04 \x01(\x08\x12\x13\n\x0b\x65nable_aigp\x18\x05 \x01(\x08\x12\"\n\x1aignore_next_hop_igp_metric\x18\x06 \x01(\x08\x12#\n\x1b\x64isable_best_path_selection\x18\x07 \x01(\x08\"\xfc\x01\n\x1aRouteSelectionOptionsState\x12\x1a\n\x12\x61lways_compare_med\x18\x01 \x01(\x08\x12\x1d\n\x15ignore_as_path_length\x18\x02 \x01(\x08\x12\"\n\x1a\x65xternal_compare_router_id\x18\x03 \x01(\x08\x12!\n\x19\x61\x64vertise_inactive_routes\x18\x04 \x01(\x08\x12\x13\n\x0b\x65nable_aigp\x18\x05 \x01(\x08\x12\"\n\x1aignore_next_hop_igp_metric\x18\x06 \x01(\x08\x12#\n\x1b\x64isable_best_path_selection\x18\x07 \x01(\x08\"}\n\x15RouteSelectionOptions\x12\x32\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\".apipb.RouteSelectionOptionsConfig\x12\x30\n\x05state\x18\x02 \x01(\x0b\x32!.apipb.RouteSelectionOptionsState\")\n\x16UseMultiplePathsConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"(\n\x15UseMultiplePathsState\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"?\n\nEbgpConfig\x12\x1a\n\x12\x61llow_multiple_asn\x18\x01 \x01(\x08\x12\x15\n\rmaximum_paths\x18\x02 \x01(\r\">\n\tEbgpState\x12\x1a\n\x12\x61llow_multiple_asn\x18\x01 \x01(\x08\x12\x15\n\rmaximum_paths\x18\x02 \x01(\r\"J\n\x04\x45\x62gp\x12!\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x11.apipb.EbgpConfig\x12\x1f\n\x05state\x18\x02 \x01(\x0b\x32\x10.apipb.EbgpState\"#\n\nIbgpConfig\x12\x15\n\rmaximum_paths\x18\x01 \x01(\r\"\"\n\tIbgpState\x12\x15\n\rmaximum_paths\x18\x01 \x01(\r\"J\n\x04Ibgp\x12!\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x11.apipb.IbgpConfig\x12\x1f\n\x05state\x18\x02 \x01(\x0b\x32\x10.apipb.IbgpState\"\xa4\x01\n\x10UseMultiplePaths\x12-\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1d.apipb.UseMultiplePathsConfig\x12+\n\x05state\x18\x02 \x01(\x0b\x32\x1c.apipb.UseMultiplePathsState\x12\x19\n\x04\x65\x62gp\x18\x03 \x01(\x0b\x32\x0b.apipb.Ebgp\x12\x19\n\x04ibgp\x18\x04 \x01(\x0b\x32\x0b.apipb.Ibgp\"4\n\x1bRouteTargetMembershipConfig\x12\x15\n\rdeferral_time\x18\x01 \x01(\r\"3\n\x1aRouteTargetMembershipState\x12\x15\n\rdeferral_time\x18\x01 \x01(\r\"}\n\x15RouteTargetMembership\x12\x32\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\".apipb.RouteTargetMembershipConfig\x12\x30\n\x05state\x18\x02 \x01(\x0b\x32!.apipb.RouteTargetMembershipState\"G\n\x1eLongLivedGracefulRestartConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0crestart_time\x18\x02 \x01(\r\"\x95\x01\n\x1dLongLivedGracefulRestartState\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x10\n\x08received\x18\x02 \x01(\x08\x12\x12\n\nadvertised\x18\x03 \x01(\x08\x12\x19\n\x11peer_restart_time\x18\x04 \x01(\r\x12\"\n\x1apeer_restart_timer_expired\x18\x05 \x01(\x08\"\x86\x01\n\x18LongLivedGracefulRestart\x12\x35\n\x06\x63onfig\x18\x01 \x01(\x0b\x32%.apipb.LongLivedGracefulRestartConfig\x12\x33\n\x05state\x18\x02 \x01(\x0b\x32$.apipb.LongLivedGracefulRestartState\"\xfc\x03\n\x07\x41\x66iSafi\x12\x35\n\x13mp_graceful_restart\x18\x01 \x01(\x0b\x32\x18.apipb.MpGracefulRestart\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.apipb.AfiSafiConfig\x12\"\n\x05state\x18\x03 \x01(\x0b\x32\x13.apipb.AfiSafiState\x12(\n\x0c\x61pply_policy\x18\x04 \x01(\x0b\x32\x12.apipb.ApplyPolicy\x12=\n\x17route_selection_options\x18\x05 \x01(\x0b\x32\x1c.apipb.RouteSelectionOptions\x12\x33\n\x12use_multiple_paths\x18\x06 \x01(\x0b\x32\x17.apipb.UseMultiplePaths\x12)\n\rprefix_limits\x18\x07 \x01(\x0b\x32\x12.apipb.PrefixLimit\x12=\n\x17route_target_membership\x18\x08 \x01(\x0b\x32\x1c.apipb.RouteTargetMembership\x12\x44\n\x1blong_lived_graceful_restart\x18\t \x01(\x0b\x32\x1f.apipb.LongLivedGracefulRestart\x12\"\n\tadd_paths\x18\n \x01(\x0b\x32\x0f.apipb.AddPaths\"3\n\x0e\x41\x64\x64PathsConfig\x12\x0f\n\x07receive\x18\x01 \x01(\x08\x12\x10\n\x08send_max\x18\x02 \x01(\r\"2\n\rAddPathsState\x12\x0f\n\x07receive\x18\x01 \x01(\x08\x12\x10\n\x08send_max\x18\x02 \x01(\r\"V\n\x08\x41\x64\x64Paths\x12%\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x15.apipb.AddPathsConfig\x12#\n\x05state\x18\x02 \x01(\x0b\x32\x14.apipb.AddPathsState\"M\n\x06Prefix\x12\x11\n\tip_prefix\x18\x01 \x01(\t\x12\x17\n\x0fmask_length_min\x18\x02 \x01(\r\x12\x17\n\x0fmask_length_max\x18\x03 \x01(\r\"s\n\nDefinedSet\x12(\n\x0c\x64\x65\x66ined_type\x18\x01 \x01(\x0e\x32\x12.apipb.DefinedType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04list\x18\x03 \x03(\t\x12\x1f\n\x08prefixes\x18\x04 \x03(\x0b\x32\r.apipb.Prefix\"b\n\x08MatchSet\x12\"\n\x04type\x18\x01 \x01(\x0e\x32\x14.apipb.MatchSet.Type\x12\x0c\n\x04name\x18\x02 \x01(\t\"$\n\x04Type\x12\x07\n\x03\x41NY\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\n\n\x06INVERT\x10\x02\"f\n\x0c\x41sPathLength\x12&\n\x04type\x18\x01 \x01(\x0e\x32\x18.apipb.AsPathLength.Type\x12\x0e\n\x06length\x18\x02 \x01(\r\"\x1e\n\x04Type\x12\x06\n\x02\x45Q\x10\x00\x12\x06\n\x02GE\x10\x01\x12\x06\n\x02LE\x10\x02\"\x9b\x04\n\nConditions\x12#\n\nprefix_set\x18\x01 \x01(\x0b\x32\x0f.apipb.MatchSet\x12%\n\x0cneighbor_set\x18\x02 \x01(\x0b\x32\x0f.apipb.MatchSet\x12+\n\x0e\x61s_path_length\x18\x03 \x01(\x0b\x32\x13.apipb.AsPathLength\x12$\n\x0b\x61s_path_set\x18\x04 \x01(\x0b\x32\x0f.apipb.MatchSet\x12&\n\rcommunity_set\x18\x05 \x01(\x0b\x32\x0f.apipb.MatchSet\x12*\n\x11\x65xt_community_set\x18\x06 \x01(\x0b\x32\x0f.apipb.MatchSet\x12\x13\n\x0brpki_result\x18\x07 \x01(\x05\x12/\n\nroute_type\x18\x08 \x01(\x0e\x32\x1b.apipb.Conditions.RouteType\x12,\n\x13large_community_set\x18\t \x01(\x0b\x32\x0f.apipb.MatchSet\x12\x18\n\x10next_hop_in_list\x18\n \x03(\t\x12\"\n\x0b\x61\x66i_safi_in\x18\x0b \x03(\x0b\x32\r.apipb.Family\"h\n\tRouteType\x12\x13\n\x0fROUTE_TYPE_NONE\x10\x00\x12\x17\n\x13ROUTE_TYPE_INTERNAL\x10\x01\x12\x17\n\x13ROUTE_TYPE_EXTERNAL\x10\x02\x12\x14\n\x10ROUTE_TYPE_LOCAL\x10\x03\"{\n\x0f\x43ommunityAction\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.apipb.CommunityAction.Type\x12\x13\n\x0b\x63ommunities\x18\x02 \x03(\t\"(\n\x04Type\x12\x07\n\x03\x41\x44\x44\x10\x00\x12\n\n\x06REMOVE\x10\x01\x12\x0b\n\x07REPLACE\x10\x02\"]\n\tMedAction\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.apipb.MedAction.Type\x12\r\n\x05value\x18\x02 \x01(\x03\"\x1c\n\x04Type\x12\x07\n\x03MOD\x10\x00\x12\x0b\n\x07REPLACE\x10\x01\"E\n\x0f\x41sPrependAction\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x0e\n\x06repeat\x18\x02 \x01(\r\x12\x15\n\ruse_left_most\x18\x03 \x01(\x08\"A\n\rNexthopAction\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04self\x18\x02 \x01(\x08\x12\x11\n\tunchanged\x18\x03 \x01(\x08\" \n\x0fLocalPrefAction\x12\r\n\x05value\x18\x01 \x01(\r\"\xdc\x02\n\x07\x41\x63tions\x12(\n\x0croute_action\x18\x01 \x01(\x0e\x32\x12.apipb.RouteAction\x12)\n\tcommunity\x18\x02 \x01(\x0b\x32\x16.apipb.CommunityAction\x12\x1d\n\x03med\x18\x03 \x01(\x0b\x32\x10.apipb.MedAction\x12*\n\nas_prepend\x18\x04 \x01(\x0b\x32\x16.apipb.AsPrependAction\x12-\n\rext_community\x18\x05 \x01(\x0b\x32\x16.apipb.CommunityAction\x12%\n\x07nexthop\x18\x06 \x01(\x0b\x32\x14.apipb.NexthopAction\x12*\n\nlocal_pref\x18\x07 \x01(\x0b\x32\x16.apipb.LocalPrefAction\x12/\n\x0flarge_community\x18\x08 \x01(\x0b\x32\x16.apipb.CommunityAction\"a\n\tStatement\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\nconditions\x18\x02 \x01(\x0b\x32\x11.apipb.Conditions\x12\x1f\n\x07\x61\x63tions\x18\x03 \x01(\x0b\x32\x0e.apipb.Actions\"<\n\x06Policy\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\nstatements\x18\x02 \x03(\x0b\x32\x10.apipb.Statement\"\x98\x01\n\x10PolicyAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\tdirection\x18\x02 \x01(\x0e\x32\x16.apipb.PolicyDirection\x12\x1f\n\x08policies\x18\x04 \x03(\x0b\x32\r.apipb.Policy\x12*\n\x0e\x64\x65\x66\x61ult_action\x18\x05 \x01(\x0e\x32\x12.apipb.RouteAction\"Y\n\rRoutingPolicy\x12\'\n\x0c\x64\x65\x66ined_sets\x18\x01 \x03(\x0b\x32\x11.apipb.DefinedSet\x12\x1f\n\x08policies\x18\x02 \x03(\x0b\x32\r.apipb.Policy\"d\n\x03Roa\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x11\n\tprefixlen\x18\x02 \x01(\r\x12\x0e\n\x06maxlen\x18\x03 \x01(\r\x12\x0e\n\x06prefix\x18\x04 \x01(\t\x12\x1d\n\x04\x63onf\x18\x05 \x01(\x0b\x32\x0f.apipb.RPKIConf\"\x93\x01\n\x03Vrf\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x02rd\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\'\n\timport_rt\x18\x03 \x03(\x0b\x32\x14.google.protobuf.Any\x12\'\n\texport_rt\x18\x04 \x03(\x0b\x32\x14.google.protobuf.Any\x12\n\n\x02id\x18\x05 \x01(\r\"X\n\x14\x44\x65\x66\x61ultRouteDistance\x12\x1f\n\x17\x65xternal_route_distance\x18\x01 \x01(\r\x12\x1f\n\x17internal_route_distance\x18\x02 \x01(\r\"\xa8\x03\n\x06Global\x12\x0b\n\x03\x61sn\x18\x01 \x01(\r\x12\x11\n\trouter_id\x18\x02 \x01(\t\x12\x13\n\x0blisten_port\x18\x03 \x01(\x05\x12\x18\n\x10listen_addresses\x18\x04 \x03(\t\x12\x10\n\x08\x66\x61milies\x18\x05 \x03(\r\x12\x1a\n\x12use_multiple_paths\x18\x06 \x01(\x08\x12\x43\n\x17route_selection_options\x18\x07 \x01(\x0b\x32\".apipb.RouteSelectionOptionsConfig\x12;\n\x16\x64\x65\x66\x61ult_route_distance\x18\x08 \x01(\x0b\x32\x1b.apipb.DefaultRouteDistance\x12+\n\rconfederation\x18\t \x01(\x0b\x32\x14.apipb.Confederation\x12\x30\n\x10graceful_restart\x18\n \x01(\x0b\x32\x16.apipb.GracefulRestart\x12(\n\x0c\x61pply_policy\x18\x0b \x01(\x0b\x32\x12.apipb.ApplyPolicy\x12\x16\n\x0e\x62ind_to_device\x18\x0c \x01(\t\"L\n\rConfederation\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x12\n\nidentifier\x18\x02 \x01(\r\x12\x16\n\x0emember_as_list\x18\x03 \x03(\r\"0\n\x08RPKIConf\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x0bremote_port\x18\x02 \x01(\r\"\x96\x03\n\tRPKIState\x12*\n\x06uptime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64owntime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\n\n\x02up\x18\x03 \x01(\x08\x12\x13\n\x0brecord_ipv4\x18\x04 \x01(\r\x12\x13\n\x0brecord_ipv6\x18\x05 \x01(\r\x12\x13\n\x0bprefix_ipv4\x18\x06 \x01(\r\x12\x13\n\x0bprefix_ipv6\x18\x07 \x01(\r\x12\x0e\n\x06serial\x18\x08 \x01(\r\x12\x15\n\rreceived_ipv4\x18\t \x01(\x03\x12\x15\n\rreceived_ipv6\x18\n \x01(\x03\x12\x15\n\rserial_notify\x18\x0b \x01(\x03\x12\x13\n\x0b\x63\x61\x63he_reset\x18\x0c \x01(\x03\x12\x16\n\x0e\x63\x61\x63he_response\x18\r \x01(\x03\x12\x13\n\x0b\x65nd_of_data\x18\x0e \x01(\x03\x12\r\n\x05\x65rror\x18\x0f \x01(\x03\x12\x14\n\x0cserial_query\x18\x10 \x01(\x03\x12\x13\n\x0breset_query\x18\x11 \x01(\x03\"F\n\x04Rpki\x12\x1d\n\x04\x63onf\x18\x01 \x01(\x0b\x32\x0f.apipb.RPKIConf\x12\x1f\n\x05state\x18\x02 \x01(\x0b\x32\x10.apipb.RPKIState\"\x98\x01\n\x12SetLogLevelRequest\x12.\n\x05level\x18\x01 \x01(\x0e\x32\x1f.apipb.SetLogLevelRequest.Level\"R\n\x05Level\x12\t\n\x05PANIC\x10\x00\x12\t\n\x05\x46\x41TAL\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x08\n\x04WARN\x10\x03\x12\x08\n\x04INFO\x10\x04\x12\t\n\x05\x44\x45\x42UG\x10\x05\x12\t\n\x05TRACE\x10\x06*D\n\tTableType\x12\n\n\x06GLOBAL\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\n\n\x06\x41\x44J_IN\x10\x02\x12\x0b\n\x07\x41\x44J_OUT\x10\x03\x12\x07\n\x03VRF\x10\x04*&\n\x08PeerType\x12\x0c\n\x08INTERNAL\x10\x00\x12\x0c\n\x08\x45XTERNAL\x10\x01*=\n\rRemovePrivate\x12\x0f\n\x0bREMOVE_NONE\x10\x00\x12\x0e\n\nREMOVE_ALL\x10\x01\x12\x0b\n\x07REPLACE\x10\x02*\x82\x01\n\x0b\x44\x65\x66inedType\x12\n\n\x06PREFIX\x10\x00\x12\x0c\n\x08NEIGHBOR\x10\x01\x12\x07\n\x03TAG\x10\x02\x12\x0b\n\x07\x41S_PATH\x10\x03\x12\r\n\tCOMMUNITY\x10\x04\x12\x11\n\rEXT_COMMUNITY\x10\x05\x12\x13\n\x0fLARGE_COMMUNITY\x10\x06\x12\x0c\n\x08NEXT_HOP\x10\x07*/\n\x0bRouteAction\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\n\n\x06REJECT\x10\x02*6\n\x0fPolicyDirection\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06IMPORT\x10\x01\x12\n\n\x06\x45XPORT\x10\x02\x32\xc2\x1d\n\x08GobgpApi\x12:\n\x08StartBgp\x12\x16.apipb.StartBgpRequest\x1a\x16.google.protobuf.Empty\x12\x38\n\x07StopBgp\x12\x15.apipb.StopBgpRequest\x1a\x16.google.protobuf.Empty\x12\x35\n\x06GetBgp\x12\x14.apipb.GetBgpRequest\x1a\x15.apipb.GetBgpResponse\x12\x43\n\nWatchEvent\x12\x18.apipb.WatchEventRequest\x1a\x19.apipb.WatchEventResponse0\x01\x12\x38\n\x07\x41\x64\x64Peer\x12\x15.apipb.AddPeerRequest\x1a\x16.google.protobuf.Empty\x12>\n\nDeletePeer\x12\x18.apipb.DeletePeerRequest\x1a\x16.google.protobuf.Empty\x12=\n\x08ListPeer\x12\x16.apipb.ListPeerRequest\x1a\x17.apipb.ListPeerResponse0\x01\x12\x41\n\nUpdatePeer\x12\x18.apipb.UpdatePeerRequest\x1a\x19.apipb.UpdatePeerResponse\x12<\n\tResetPeer\x12\x17.apipb.ResetPeerRequest\x1a\x16.google.protobuf.Empty\x12\x42\n\x0cShutdownPeer\x12\x1a.apipb.ShutdownPeerRequest\x1a\x16.google.protobuf.Empty\x12>\n\nEnablePeer\x12\x18.apipb.EnablePeerRequest\x1a\x16.google.protobuf.Empty\x12@\n\x0b\x44isablePeer\x12\x19.apipb.DisablePeerRequest\x1a\x16.google.protobuf.Empty\x12\x42\n\x0c\x41\x64\x64PeerGroup\x12\x1a.apipb.AddPeerGroupRequest\x1a\x16.google.protobuf.Empty\x12H\n\x0f\x44\x65letePeerGroup\x12\x1d.apipb.DeletePeerGroupRequest\x1a\x16.google.protobuf.Empty\x12L\n\rListPeerGroup\x12\x1b.apipb.ListPeerGroupRequest\x1a\x1c.apipb.ListPeerGroupResponse0\x01\x12P\n\x0fUpdatePeerGroup\x12\x1d.apipb.UpdatePeerGroupRequest\x1a\x1e.apipb.UpdatePeerGroupResponse\x12N\n\x12\x41\x64\x64\x44ynamicNeighbor\x12 .apipb.AddDynamicNeighborRequest\x1a\x16.google.protobuf.Empty\x12^\n\x13ListDynamicNeighbor\x12!.apipb.ListDynamicNeighborRequest\x1a\".apipb.ListDynamicNeighborResponse0\x01\x12T\n\x15\x44\x65leteDynamicNeighbor\x12#.apipb.DeleteDynamicNeighborRequest\x1a\x16.google.protobuf.Empty\x12\x38\n\x07\x41\x64\x64Path\x12\x15.apipb.AddPathRequest\x1a\x16.apipb.AddPathResponse\x12>\n\nDeletePath\x12\x18.apipb.DeletePathRequest\x1a\x16.google.protobuf.Empty\x12=\n\x08ListPath\x12\x16.apipb.ListPathRequest\x1a\x17.apipb.ListPathResponse0\x01\x12\x46\n\rAddPathStream\x12\x1b.apipb.AddPathStreamRequest\x1a\x16.google.protobuf.Empty(\x01\x12;\n\x08GetTable\x12\x16.apipb.GetTableRequest\x1a\x17.apipb.GetTableResponse\x12\x36\n\x06\x41\x64\x64Vrf\x12\x14.apipb.AddVrfRequest\x1a\x16.google.protobuf.Empty\x12<\n\tDeleteVrf\x12\x17.apipb.DeleteVrfRequest\x1a\x16.google.protobuf.Empty\x12:\n\x07ListVrf\x12\x15.apipb.ListVrfRequest\x1a\x16.apipb.ListVrfResponse0\x01\x12<\n\tAddPolicy\x12\x17.apipb.AddPolicyRequest\x1a\x16.google.protobuf.Empty\x12\x42\n\x0c\x44\x65letePolicy\x12\x1a.apipb.DeletePolicyRequest\x1a\x16.google.protobuf.Empty\x12\x43\n\nListPolicy\x12\x18.apipb.ListPolicyRequest\x1a\x19.apipb.ListPolicyResponse0\x01\x12@\n\x0bSetPolicies\x12\x19.apipb.SetPoliciesRequest\x1a\x16.google.protobuf.Empty\x12\x44\n\rAddDefinedSet\x12\x1b.apipb.AddDefinedSetRequest\x1a\x16.google.protobuf.Empty\x12J\n\x10\x44\x65leteDefinedSet\x12\x1e.apipb.DeleteDefinedSetRequest\x1a\x16.google.protobuf.Empty\x12O\n\x0eListDefinedSet\x12\x1c.apipb.ListDefinedSetRequest\x1a\x1d.apipb.ListDefinedSetResponse0\x01\x12\x42\n\x0c\x41\x64\x64Statement\x12\x1a.apipb.AddStatementRequest\x1a\x16.google.protobuf.Empty\x12H\n\x0f\x44\x65leteStatement\x12\x1d.apipb.DeleteStatementRequest\x1a\x16.google.protobuf.Empty\x12L\n\rListStatement\x12\x1b.apipb.ListStatementRequest\x1a\x1c.apipb.ListStatementResponse0\x01\x12P\n\x13\x41\x64\x64PolicyAssignment\x12!.apipb.AddPolicyAssignmentRequest\x1a\x16.google.protobuf.Empty\x12V\n\x16\x44\x65letePolicyAssignment\x12$.apipb.DeletePolicyAssignmentRequest\x1a\x16.google.protobuf.Empty\x12\x61\n\x14ListPolicyAssignment\x12\".apipb.ListPolicyAssignmentRequest\x1a#.apipb.ListPolicyAssignmentResponse0\x01\x12P\n\x13SetPolicyAssignment\x12!.apipb.SetPolicyAssignmentRequest\x1a\x16.google.protobuf.Empty\x12\x38\n\x07\x41\x64\x64Rpki\x12\x15.apipb.AddRpkiRequest\x1a\x16.google.protobuf.Empty\x12>\n\nDeleteRpki\x12\x18.apipb.DeleteRpkiRequest\x1a\x16.google.protobuf.Empty\x12=\n\x08ListRpki\x12\x16.apipb.ListRpkiRequest\x1a\x17.apipb.ListRpkiResponse0\x01\x12>\n\nEnableRpki\x12\x18.apipb.EnableRpkiRequest\x1a\x16.google.protobuf.Empty\x12@\n\x0b\x44isableRpki\x12\x19.apipb.DisableRpkiRequest\x1a\x16.google.protobuf.Empty\x12<\n\tResetRpki\x12\x17.apipb.ResetRpkiRequest\x1a\x16.google.protobuf.Empty\x12L\n\rListRpkiTable\x12\x1b.apipb.ListRpkiTableRequest\x1a\x1c.apipb.ListRpkiTableResponse0\x01\x12@\n\x0b\x45nableZebra\x12\x19.apipb.EnableZebraRequest\x1a\x16.google.protobuf.Empty\x12<\n\tEnableMrt\x12\x17.apipb.EnableMrtRequest\x1a\x16.google.protobuf.Empty\x12>\n\nDisableMrt\x12\x18.apipb.DisableMrtRequest\x1a\x16.google.protobuf.Empty\x12\x36\n\x06\x41\x64\x64\x42mp\x12\x14.apipb.AddBmpRequest\x1a\x16.google.protobuf.Empty\x12<\n\tDeleteBmp\x12\x17.apipb.DeleteBmpRequest\x1a\x16.google.protobuf.Empty\x12:\n\x07ListBmp\x12\x15.apipb.ListBmpRequest\x1a\x16.apipb.ListBmpResponse0\x01\x12@\n\x0bSetLogLevel\x12\x19.apipb.SetLogLevelRequest\x1a\x16.google.protobuf.EmptyB$Z\"github.com/osrg/gobgp/v3/api;apipbb\x06proto3')

_TABLETYPE = DESCRIPTOR.enum_types_by_name['TableType']
TableType = enum_type_wrapper.EnumTypeWrapper(_TABLETYPE)
_PEERTYPE = DESCRIPTOR.enum_types_by_name['PeerType']
PeerType = enum_type_wrapper.EnumTypeWrapper(_PEERTYPE)
_REMOVEPRIVATE = DESCRIPTOR.enum_types_by_name['RemovePrivate']
RemovePrivate = enum_type_wrapper.EnumTypeWrapper(_REMOVEPRIVATE)
_DEFINEDTYPE = DESCRIPTOR.enum_types_by_name['DefinedType']
DefinedType = enum_type_wrapper.EnumTypeWrapper(_DEFINEDTYPE)
_ROUTEACTION = DESCRIPTOR.enum_types_by_name['RouteAction']
RouteAction = enum_type_wrapper.EnumTypeWrapper(_ROUTEACTION)
_POLICYDIRECTION = DESCRIPTOR.enum_types_by_name['PolicyDirection']
PolicyDirection = enum_type_wrapper.EnumTypeWrapper(_POLICYDIRECTION)
GLOBAL = 0
LOCAL = 1
ADJ_IN = 2
ADJ_OUT = 3
VRF = 4
INTERNAL = 0
EXTERNAL = 1
REMOVE_NONE = 0
REMOVE_ALL = 1
REPLACE = 2
PREFIX = 0
NEIGHBOR = 1
TAG = 2
AS_PATH = 3
COMMUNITY = 4
EXT_COMMUNITY = 5
LARGE_COMMUNITY = 6
NEXT_HOP = 7
NONE = 0
ACCEPT = 1
REJECT = 2
UNKNOWN = 0
IMPORT = 1
EXPORT = 2


_STARTBGPREQUEST = DESCRIPTOR.message_types_by_name['StartBgpRequest']
_STOPBGPREQUEST = DESCRIPTOR.message_types_by_name['StopBgpRequest']
_GETBGPREQUEST = DESCRIPTOR.message_types_by_name['GetBgpRequest']
_GETBGPRESPONSE = DESCRIPTOR.message_types_by_name['GetBgpResponse']
_WATCHEVENTREQUEST = DESCRIPTOR.message_types_by_name['WatchEventRequest']
_WATCHEVENTREQUEST_PEER = _WATCHEVENTREQUEST.nested_types_by_name['Peer']
_WATCHEVENTREQUEST_TABLE = _WATCHEVENTREQUEST.nested_types_by_name['Table']
_WATCHEVENTREQUEST_TABLE_FILTER = _WATCHEVENTREQUEST_TABLE.nested_types_by_name['Filter']
_WATCHEVENTRESPONSE = DESCRIPTOR.message_types_by_name['WatchEventResponse']
_WATCHEVENTRESPONSE_PEEREVENT = _WATCHEVENTRESPONSE.nested_types_by_name['PeerEvent']
_WATCHEVENTRESPONSE_TABLEEVENT = _WATCHEVENTRESPONSE.nested_types_by_name['TableEvent']
_ADDPEERREQUEST = DESCRIPTOR.message_types_by_name['AddPeerRequest']
_DELETEPEERREQUEST = DESCRIPTOR.message_types_by_name['DeletePeerRequest']
_LISTPEERREQUEST = DESCRIPTOR.message_types_by_name['ListPeerRequest']
_LISTPEERRESPONSE = DESCRIPTOR.message_types_by_name['ListPeerResponse']
_UPDATEPEERREQUEST = DESCRIPTOR.message_types_by_name['UpdatePeerRequest']
_UPDATEPEERRESPONSE = DESCRIPTOR.message_types_by_name['UpdatePeerResponse']
_RESETPEERREQUEST = DESCRIPTOR.message_types_by_name['ResetPeerRequest']
_SHUTDOWNPEERREQUEST = DESCRIPTOR.message_types_by_name['ShutdownPeerRequest']
_ENABLEPEERREQUEST = DESCRIPTOR.message_types_by_name['EnablePeerRequest']
_DISABLEPEERREQUEST = DESCRIPTOR.message_types_by_name['DisablePeerRequest']
_ADDPEERGROUPREQUEST = DESCRIPTOR.message_types_by_name['AddPeerGroupRequest']
_DELETEPEERGROUPREQUEST = DESCRIPTOR.message_types_by_name['DeletePeerGroupRequest']
_UPDATEPEERGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdatePeerGroupRequest']
_UPDATEPEERGROUPRESPONSE = DESCRIPTOR.message_types_by_name['UpdatePeerGroupResponse']
_LISTPEERGROUPREQUEST = DESCRIPTOR.message_types_by_name['ListPeerGroupRequest']
_LISTPEERGROUPRESPONSE = DESCRIPTOR.message_types_by_name['ListPeerGroupResponse']
_ADDDYNAMICNEIGHBORREQUEST = DESCRIPTOR.message_types_by_name['AddDynamicNeighborRequest']
_DELETEDYNAMICNEIGHBORREQUEST = DESCRIPTOR.message_types_by_name['DeleteDynamicNeighborRequest']
_LISTDYNAMICNEIGHBORREQUEST = DESCRIPTOR.message_types_by_name['ListDynamicNeighborRequest']
_LISTDYNAMICNEIGHBORRESPONSE = DESCRIPTOR.message_types_by_name['ListDynamicNeighborResponse']
_ADDPATHREQUEST = DESCRIPTOR.message_types_by_name['AddPathRequest']
_ADDPATHRESPONSE = DESCRIPTOR.message_types_by_name['AddPathResponse']
_DELETEPATHREQUEST = DESCRIPTOR.message_types_by_name['DeletePathRequest']
_TABLELOOKUPPREFIX = DESCRIPTOR.message_types_by_name['TableLookupPrefix']
_LISTPATHREQUEST = DESCRIPTOR.message_types_by_name['ListPathRequest']
_LISTPATHRESPONSE = DESCRIPTOR.message_types_by_name['ListPathResponse']
_ADDPATHSTREAMREQUEST = DESCRIPTOR.message_types_by_name['AddPathStreamRequest']
_GETTABLEREQUEST = DESCRIPTOR.message_types_by_name['GetTableRequest']
_GETTABLERESPONSE = DESCRIPTOR.message_types_by_name['GetTableResponse']
_ADDVRFREQUEST = DESCRIPTOR.message_types_by_name['AddVrfRequest']
_DELETEVRFREQUEST = DESCRIPTOR.message_types_by_name['DeleteVrfRequest']
_LISTVRFREQUEST = DESCRIPTOR.message_types_by_name['ListVrfRequest']
_LISTVRFRESPONSE = DESCRIPTOR.message_types_by_name['ListVrfResponse']
_ADDPOLICYREQUEST = DESCRIPTOR.message_types_by_name['AddPolicyRequest']
_DELETEPOLICYREQUEST = DESCRIPTOR.message_types_by_name['DeletePolicyRequest']
_LISTPOLICYREQUEST = DESCRIPTOR.message_types_by_name['ListPolicyRequest']
_LISTPOLICYRESPONSE = DESCRIPTOR.message_types_by_name['ListPolicyResponse']
_SETPOLICIESREQUEST = DESCRIPTOR.message_types_by_name['SetPoliciesRequest']
_ADDDEFINEDSETREQUEST = DESCRIPTOR.message_types_by_name['AddDefinedSetRequest']
_DELETEDEFINEDSETREQUEST = DESCRIPTOR.message_types_by_name['DeleteDefinedSetRequest']
_LISTDEFINEDSETREQUEST = DESCRIPTOR.message_types_by_name['ListDefinedSetRequest']
_LISTDEFINEDSETRESPONSE = DESCRIPTOR.message_types_by_name['ListDefinedSetResponse']
_ADDSTATEMENTREQUEST = DESCRIPTOR.message_types_by_name['AddStatementRequest']
_DELETESTATEMENTREQUEST = DESCRIPTOR.message_types_by_name['DeleteStatementRequest']
_LISTSTATEMENTREQUEST = DESCRIPTOR.message_types_by_name['ListStatementRequest']
_LISTSTATEMENTRESPONSE = DESCRIPTOR.message_types_by_name['ListStatementResponse']
_ADDPOLICYASSIGNMENTREQUEST = DESCRIPTOR.message_types_by_name['AddPolicyAssignmentRequest']
_DELETEPOLICYASSIGNMENTREQUEST = DESCRIPTOR.message_types_by_name['DeletePolicyAssignmentRequest']
_LISTPOLICYASSIGNMENTREQUEST = DESCRIPTOR.message_types_by_name['ListPolicyAssignmentRequest']
_LISTPOLICYASSIGNMENTRESPONSE = DESCRIPTOR.message_types_by_name['ListPolicyAssignmentResponse']
_SETPOLICYASSIGNMENTREQUEST = DESCRIPTOR.message_types_by_name['SetPolicyAssignmentRequest']
_ADDRPKIREQUEST = DESCRIPTOR.message_types_by_name['AddRpkiRequest']
_DELETERPKIREQUEST = DESCRIPTOR.message_types_by_name['DeleteRpkiRequest']
_LISTRPKIREQUEST = DESCRIPTOR.message_types_by_name['ListRpkiRequest']
_LISTRPKIRESPONSE = DESCRIPTOR.message_types_by_name['ListRpkiResponse']
_ENABLERPKIREQUEST = DESCRIPTOR.message_types_by_name['EnableRpkiRequest']
_DISABLERPKIREQUEST = DESCRIPTOR.message_types_by_name['DisableRpkiRequest']
_RESETRPKIREQUEST = DESCRIPTOR.message_types_by_name['ResetRpkiRequest']
_LISTRPKITABLEREQUEST = DESCRIPTOR.message_types_by_name['ListRpkiTableRequest']
_LISTRPKITABLERESPONSE = DESCRIPTOR.message_types_by_name['ListRpkiTableResponse']
_ENABLEZEBRAREQUEST = DESCRIPTOR.message_types_by_name['EnableZebraRequest']
_ENABLEMRTREQUEST = DESCRIPTOR.message_types_by_name['EnableMrtRequest']
_DISABLEMRTREQUEST = DESCRIPTOR.message_types_by_name['DisableMrtRequest']
_ADDBMPREQUEST = DESCRIPTOR.message_types_by_name['AddBmpRequest']
_DELETEBMPREQUEST = DESCRIPTOR.message_types_by_name['DeleteBmpRequest']
_LISTBMPREQUEST = DESCRIPTOR.message_types_by_name['ListBmpRequest']
_LISTBMPRESPONSE = DESCRIPTOR.message_types_by_name['ListBmpResponse']
_LISTBMPRESPONSE_BMPSTATION = _LISTBMPRESPONSE.nested_types_by_name['BmpStation']
_LISTBMPRESPONSE_BMPSTATION_CONF = _LISTBMPRESPONSE_BMPSTATION.nested_types_by_name['Conf']
_LISTBMPRESPONSE_BMPSTATION_STATE = _LISTBMPRESPONSE_BMPSTATION.nested_types_by_name['State']
_FAMILY = DESCRIPTOR.message_types_by_name['Family']
_VALIDATION = DESCRIPTOR.message_types_by_name['Validation']
_PATH = DESCRIPTOR.message_types_by_name['Path']
_DESTINATION = DESCRIPTOR.message_types_by_name['Destination']
_PEER = DESCRIPTOR.message_types_by_name['Peer']
_PEERGROUP = DESCRIPTOR.message_types_by_name['PeerGroup']
_DYNAMICNEIGHBOR = DESCRIPTOR.message_types_by_name['DynamicNeighbor']
_APPLYPOLICY = DESCRIPTOR.message_types_by_name['ApplyPolicy']
_PREFIXLIMIT = DESCRIPTOR.message_types_by_name['PrefixLimit']
_PEERCONF = DESCRIPTOR.message_types_by_name['PeerConf']
_PEERGROUPCONF = DESCRIPTOR.message_types_by_name['PeerGroupConf']
_PEERGROUPSTATE = DESCRIPTOR.message_types_by_name['PeerGroupState']
_TTLSECURITY = DESCRIPTOR.message_types_by_name['TtlSecurity']
_EBGPMULTIHOP = DESCRIPTOR.message_types_by_name['EbgpMultihop']
_ROUTEREFLECTOR = DESCRIPTOR.message_types_by_name['RouteReflector']
_PEERSTATE = DESCRIPTOR.message_types_by_name['PeerState']
_MESSAGES = DESCRIPTOR.message_types_by_name['Messages']
_MESSAGE = DESCRIPTOR.message_types_by_name['Message']
_QUEUES = DESCRIPTOR.message_types_by_name['Queues']
_TIMERS = DESCRIPTOR.message_types_by_name['Timers']
_TIMERSCONFIG = DESCRIPTOR.message_types_by_name['TimersConfig']
_TIMERSSTATE = DESCRIPTOR.message_types_by_name['TimersState']
_TRANSPORT = DESCRIPTOR.message_types_by_name['Transport']
_ROUTESERVER = DESCRIPTOR.message_types_by_name['RouteServer']
_GRACEFULRESTART = DESCRIPTOR.message_types_by_name['GracefulRestart']
_MPGRACEFULRESTARTCONFIG = DESCRIPTOR.message_types_by_name['MpGracefulRestartConfig']
_MPGRACEFULRESTARTSTATE = DESCRIPTOR.message_types_by_name['MpGracefulRestartState']
_MPGRACEFULRESTART = DESCRIPTOR.message_types_by_name['MpGracefulRestart']
_AFISAFICONFIG = DESCRIPTOR.message_types_by_name['AfiSafiConfig']
_AFISAFISTATE = DESCRIPTOR.message_types_by_name['AfiSafiState']
_ROUTESELECTIONOPTIONSCONFIG = DESCRIPTOR.message_types_by_name['RouteSelectionOptionsConfig']
_ROUTESELECTIONOPTIONSSTATE = DESCRIPTOR.message_types_by_name['RouteSelectionOptionsState']
_ROUTESELECTIONOPTIONS = DESCRIPTOR.message_types_by_name['RouteSelectionOptions']
_USEMULTIPLEPATHSCONFIG = DESCRIPTOR.message_types_by_name['UseMultiplePathsConfig']
_USEMULTIPLEPATHSSTATE = DESCRIPTOR.message_types_by_name['UseMultiplePathsState']
_EBGPCONFIG = DESCRIPTOR.message_types_by_name['EbgpConfig']
_EBGPSTATE = DESCRIPTOR.message_types_by_name['EbgpState']
_EBGP = DESCRIPTOR.message_types_by_name['Ebgp']
_IBGPCONFIG = DESCRIPTOR.message_types_by_name['IbgpConfig']
_IBGPSTATE = DESCRIPTOR.message_types_by_name['IbgpState']
_IBGP = DESCRIPTOR.message_types_by_name['Ibgp']
_USEMULTIPLEPATHS = DESCRIPTOR.message_types_by_name['UseMultiplePaths']
_ROUTETARGETMEMBERSHIPCONFIG = DESCRIPTOR.message_types_by_name['RouteTargetMembershipConfig']
_ROUTETARGETMEMBERSHIPSTATE = DESCRIPTOR.message_types_by_name['RouteTargetMembershipState']
_ROUTETARGETMEMBERSHIP = DESCRIPTOR.message_types_by_name['RouteTargetMembership']
_LONGLIVEDGRACEFULRESTARTCONFIG = DESCRIPTOR.message_types_by_name['LongLivedGracefulRestartConfig']
_LONGLIVEDGRACEFULRESTARTSTATE = DESCRIPTOR.message_types_by_name['LongLivedGracefulRestartState']
_LONGLIVEDGRACEFULRESTART = DESCRIPTOR.message_types_by_name['LongLivedGracefulRestart']
_AFISAFI = DESCRIPTOR.message_types_by_name['AfiSafi']
_ADDPATHSCONFIG = DESCRIPTOR.message_types_by_name['AddPathsConfig']
_ADDPATHSSTATE = DESCRIPTOR.message_types_by_name['AddPathsState']
_ADDPATHS = DESCRIPTOR.message_types_by_name['AddPaths']
_PREFIX = DESCRIPTOR.message_types_by_name['Prefix']
_DEFINEDSET = DESCRIPTOR.message_types_by_name['DefinedSet']
_MATCHSET = DESCRIPTOR.message_types_by_name['MatchSet']
_ASPATHLENGTH = DESCRIPTOR.message_types_by_name['AsPathLength']
_CONDITIONS = DESCRIPTOR.message_types_by_name['Conditions']
_COMMUNITYACTION = DESCRIPTOR.message_types_by_name['CommunityAction']
_MEDACTION = DESCRIPTOR.message_types_by_name['MedAction']
_ASPREPENDACTION = DESCRIPTOR.message_types_by_name['AsPrependAction']
_NEXTHOPACTION = DESCRIPTOR.message_types_by_name['NexthopAction']
_LOCALPREFACTION = DESCRIPTOR.message_types_by_name['LocalPrefAction']
_ACTIONS = DESCRIPTOR.message_types_by_name['Actions']
_STATEMENT = DESCRIPTOR.message_types_by_name['Statement']
_POLICY = DESCRIPTOR.message_types_by_name['Policy']
_POLICYASSIGNMENT = DESCRIPTOR.message_types_by_name['PolicyAssignment']
_ROUTINGPOLICY = DESCRIPTOR.message_types_by_name['RoutingPolicy']
_ROA = DESCRIPTOR.message_types_by_name['Roa']
_VRF = DESCRIPTOR.message_types_by_name['Vrf']
_DEFAULTROUTEDISTANCE = DESCRIPTOR.message_types_by_name['DefaultRouteDistance']
_GLOBAL = DESCRIPTOR.message_types_by_name['Global']
_CONFEDERATION = DESCRIPTOR.message_types_by_name['Confederation']
_RPKICONF = DESCRIPTOR.message_types_by_name['RPKIConf']
_RPKISTATE = DESCRIPTOR.message_types_by_name['RPKIState']
_RPKI = DESCRIPTOR.message_types_by_name['Rpki']
_SETLOGLEVELREQUEST = DESCRIPTOR.message_types_by_name['SetLogLevelRequest']
_WATCHEVENTREQUEST_TABLE_FILTER_TYPE = _WATCHEVENTREQUEST_TABLE_FILTER.enum_types_by_name['Type']
_WATCHEVENTRESPONSE_PEEREVENT_TYPE = _WATCHEVENTRESPONSE_PEEREVENT.enum_types_by_name['Type']
_RESETPEERREQUEST_SOFTRESETDIRECTION = _RESETPEERREQUEST.enum_types_by_name['SoftResetDirection']
_TABLELOOKUPPREFIX_TYPE = _TABLELOOKUPPREFIX.enum_types_by_name['Type']
_LISTPATHREQUEST_SORTTYPE = _LISTPATHREQUEST.enum_types_by_name['SortType']
_ENABLEMRTREQUEST_DUMPTYPE = _ENABLEMRTREQUEST.enum_types_by_name['DumpType']
_ADDBMPREQUEST_MONITORINGPOLICY = _ADDBMPREQUEST.enum_types_by_name['MonitoringPolicy']
_FAMILY_AFI = _FAMILY.enum_types_by_name['Afi']
_FAMILY_SAFI = _FAMILY.enum_types_by_name['Safi']
_VALIDATION_STATE = _VALIDATION.enum_types_by_name['State']
_VALIDATION_REASON = _VALIDATION.enum_types_by_name['Reason']
_PEERSTATE_SESSIONSTATE = _PEERSTATE.enum_types_by_name['SessionState']
_PEERSTATE_ADMINSTATE = _PEERSTATE.enum_types_by_name['AdminState']
_MATCHSET_TYPE = _MATCHSET.enum_types_by_name['Type']
_ASPATHLENGTH_TYPE = _ASPATHLENGTH.enum_types_by_name['Type']
_CONDITIONS_ROUTETYPE = _CONDITIONS.enum_types_by_name['RouteType']
_COMMUNITYACTION_TYPE = _COMMUNITYACTION.enum_types_by_name['Type']
_MEDACTION_TYPE = _MEDACTION.enum_types_by_name['Type']
_SETLOGLEVELREQUEST_LEVEL = _SETLOGLEVELREQUEST.enum_types_by_name['Level']
StartBgpRequest = _reflection.GeneratedProtocolMessageType('StartBgpRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTBGPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.StartBgpRequest)
  })
_sym_db.RegisterMessage(StartBgpRequest)

StopBgpRequest = _reflection.GeneratedProtocolMessageType('StopBgpRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPBGPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.StopBgpRequest)
  })
_sym_db.RegisterMessage(StopBgpRequest)

GetBgpRequest = _reflection.GeneratedProtocolMessageType('GetBgpRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBGPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.GetBgpRequest)
  })
_sym_db.RegisterMessage(GetBgpRequest)

GetBgpResponse = _reflection.GeneratedProtocolMessageType('GetBgpResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBGPRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.GetBgpResponse)
  })
_sym_db.RegisterMessage(GetBgpResponse)

WatchEventRequest = _reflection.GeneratedProtocolMessageType('WatchEventRequest', (_message.Message,), {

  'Peer' : _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), {
    'DESCRIPTOR' : _WATCHEVENTREQUEST_PEER,
    '__module__' : 'gobgp_pb2'
    # @@protoc_insertion_point(class_scope:apipb.WatchEventRequest.Peer)
    })
  ,

  'Table' : _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {

    'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
      'DESCRIPTOR' : _WATCHEVENTREQUEST_TABLE_FILTER,
      '__module__' : 'gobgp_pb2'
      # @@protoc_insertion_point(class_scope:apipb.WatchEventRequest.Table.Filter)
      })
    ,
    'DESCRIPTOR' : _WATCHEVENTREQUEST_TABLE,
    '__module__' : 'gobgp_pb2'
    # @@protoc_insertion_point(class_scope:apipb.WatchEventRequest.Table)
    })
  ,
  'DESCRIPTOR' : _WATCHEVENTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.WatchEventRequest)
  })
_sym_db.RegisterMessage(WatchEventRequest)
_sym_db.RegisterMessage(WatchEventRequest.Peer)
_sym_db.RegisterMessage(WatchEventRequest.Table)
_sym_db.RegisterMessage(WatchEventRequest.Table.Filter)

WatchEventResponse = _reflection.GeneratedProtocolMessageType('WatchEventResponse', (_message.Message,), {

  'PeerEvent' : _reflection.GeneratedProtocolMessageType('PeerEvent', (_message.Message,), {
    'DESCRIPTOR' : _WATCHEVENTRESPONSE_PEEREVENT,
    '__module__' : 'gobgp_pb2'
    # @@protoc_insertion_point(class_scope:apipb.WatchEventResponse.PeerEvent)
    })
  ,

  'TableEvent' : _reflection.GeneratedProtocolMessageType('TableEvent', (_message.Message,), {
    'DESCRIPTOR' : _WATCHEVENTRESPONSE_TABLEEVENT,
    '__module__' : 'gobgp_pb2'
    # @@protoc_insertion_point(class_scope:apipb.WatchEventResponse.TableEvent)
    })
  ,
  'DESCRIPTOR' : _WATCHEVENTRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.WatchEventResponse)
  })
_sym_db.RegisterMessage(WatchEventResponse)
_sym_db.RegisterMessage(WatchEventResponse.PeerEvent)
_sym_db.RegisterMessage(WatchEventResponse.TableEvent)

AddPeerRequest = _reflection.GeneratedProtocolMessageType('AddPeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPEERREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPeerRequest)
  })
_sym_db.RegisterMessage(AddPeerRequest)

DeletePeerRequest = _reflection.GeneratedProtocolMessageType('DeletePeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPEERREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeletePeerRequest)
  })
_sym_db.RegisterMessage(DeletePeerRequest)

ListPeerRequest = _reflection.GeneratedProtocolMessageType('ListPeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPEERREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPeerRequest)
  })
_sym_db.RegisterMessage(ListPeerRequest)

ListPeerResponse = _reflection.GeneratedProtocolMessageType('ListPeerResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPEERRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPeerResponse)
  })
_sym_db.RegisterMessage(ListPeerResponse)

UpdatePeerRequest = _reflection.GeneratedProtocolMessageType('UpdatePeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPEERREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UpdatePeerRequest)
  })
_sym_db.RegisterMessage(UpdatePeerRequest)

UpdatePeerResponse = _reflection.GeneratedProtocolMessageType('UpdatePeerResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPEERRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UpdatePeerResponse)
  })
_sym_db.RegisterMessage(UpdatePeerResponse)

ResetPeerRequest = _reflection.GeneratedProtocolMessageType('ResetPeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETPEERREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ResetPeerRequest)
  })
_sym_db.RegisterMessage(ResetPeerRequest)

ShutdownPeerRequest = _reflection.GeneratedProtocolMessageType('ShutdownPeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNPEERREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ShutdownPeerRequest)
  })
_sym_db.RegisterMessage(ShutdownPeerRequest)

EnablePeerRequest = _reflection.GeneratedProtocolMessageType('EnablePeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEPEERREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EnablePeerRequest)
  })
_sym_db.RegisterMessage(EnablePeerRequest)

DisablePeerRequest = _reflection.GeneratedProtocolMessageType('DisablePeerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEPEERREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DisablePeerRequest)
  })
_sym_db.RegisterMessage(DisablePeerRequest)

AddPeerGroupRequest = _reflection.GeneratedProtocolMessageType('AddPeerGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPEERGROUPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPeerGroupRequest)
  })
_sym_db.RegisterMessage(AddPeerGroupRequest)

DeletePeerGroupRequest = _reflection.GeneratedProtocolMessageType('DeletePeerGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPEERGROUPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeletePeerGroupRequest)
  })
_sym_db.RegisterMessage(DeletePeerGroupRequest)

UpdatePeerGroupRequest = _reflection.GeneratedProtocolMessageType('UpdatePeerGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPEERGROUPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UpdatePeerGroupRequest)
  })
_sym_db.RegisterMessage(UpdatePeerGroupRequest)

UpdatePeerGroupResponse = _reflection.GeneratedProtocolMessageType('UpdatePeerGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPEERGROUPRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UpdatePeerGroupResponse)
  })
_sym_db.RegisterMessage(UpdatePeerGroupResponse)

ListPeerGroupRequest = _reflection.GeneratedProtocolMessageType('ListPeerGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPEERGROUPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPeerGroupRequest)
  })
_sym_db.RegisterMessage(ListPeerGroupRequest)

ListPeerGroupResponse = _reflection.GeneratedProtocolMessageType('ListPeerGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPEERGROUPRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPeerGroupResponse)
  })
_sym_db.RegisterMessage(ListPeerGroupResponse)

AddDynamicNeighborRequest = _reflection.GeneratedProtocolMessageType('AddDynamicNeighborRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDDYNAMICNEIGHBORREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddDynamicNeighborRequest)
  })
_sym_db.RegisterMessage(AddDynamicNeighborRequest)

DeleteDynamicNeighborRequest = _reflection.GeneratedProtocolMessageType('DeleteDynamicNeighborRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDYNAMICNEIGHBORREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeleteDynamicNeighborRequest)
  })
_sym_db.RegisterMessage(DeleteDynamicNeighborRequest)

ListDynamicNeighborRequest = _reflection.GeneratedProtocolMessageType('ListDynamicNeighborRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDYNAMICNEIGHBORREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListDynamicNeighborRequest)
  })
_sym_db.RegisterMessage(ListDynamicNeighborRequest)

ListDynamicNeighborResponse = _reflection.GeneratedProtocolMessageType('ListDynamicNeighborResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDYNAMICNEIGHBORRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListDynamicNeighborResponse)
  })
_sym_db.RegisterMessage(ListDynamicNeighborResponse)

AddPathRequest = _reflection.GeneratedProtocolMessageType('AddPathRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPATHREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPathRequest)
  })
_sym_db.RegisterMessage(AddPathRequest)

AddPathResponse = _reflection.GeneratedProtocolMessageType('AddPathResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDPATHRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPathResponse)
  })
_sym_db.RegisterMessage(AddPathResponse)

DeletePathRequest = _reflection.GeneratedProtocolMessageType('DeletePathRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPATHREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeletePathRequest)
  })
_sym_db.RegisterMessage(DeletePathRequest)

TableLookupPrefix = _reflection.GeneratedProtocolMessageType('TableLookupPrefix', (_message.Message,), {
  'DESCRIPTOR' : _TABLELOOKUPPREFIX,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TableLookupPrefix)
  })
_sym_db.RegisterMessage(TableLookupPrefix)

ListPathRequest = _reflection.GeneratedProtocolMessageType('ListPathRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPATHREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPathRequest)
  })
_sym_db.RegisterMessage(ListPathRequest)

ListPathResponse = _reflection.GeneratedProtocolMessageType('ListPathResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPATHRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPathResponse)
  })
_sym_db.RegisterMessage(ListPathResponse)

AddPathStreamRequest = _reflection.GeneratedProtocolMessageType('AddPathStreamRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPATHSTREAMREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPathStreamRequest)
  })
_sym_db.RegisterMessage(AddPathStreamRequest)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)

AddVrfRequest = _reflection.GeneratedProtocolMessageType('AddVrfRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDVRFREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddVrfRequest)
  })
_sym_db.RegisterMessage(AddVrfRequest)

DeleteVrfRequest = _reflection.GeneratedProtocolMessageType('DeleteVrfRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVRFREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeleteVrfRequest)
  })
_sym_db.RegisterMessage(DeleteVrfRequest)

ListVrfRequest = _reflection.GeneratedProtocolMessageType('ListVrfRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVRFREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListVrfRequest)
  })
_sym_db.RegisterMessage(ListVrfRequest)

ListVrfResponse = _reflection.GeneratedProtocolMessageType('ListVrfResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVRFRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListVrfResponse)
  })
_sym_db.RegisterMessage(ListVrfResponse)

AddPolicyRequest = _reflection.GeneratedProtocolMessageType('AddPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPOLICYREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPolicyRequest)
  })
_sym_db.RegisterMessage(AddPolicyRequest)

DeletePolicyRequest = _reflection.GeneratedProtocolMessageType('DeletePolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOLICYREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeletePolicyRequest)
  })
_sym_db.RegisterMessage(DeletePolicyRequest)

ListPolicyRequest = _reflection.GeneratedProtocolMessageType('ListPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOLICYREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPolicyRequest)
  })
_sym_db.RegisterMessage(ListPolicyRequest)

ListPolicyResponse = _reflection.GeneratedProtocolMessageType('ListPolicyResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOLICYRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPolicyResponse)
  })
_sym_db.RegisterMessage(ListPolicyResponse)

SetPoliciesRequest = _reflection.GeneratedProtocolMessageType('SetPoliciesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPOLICIESREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SetPoliciesRequest)
  })
_sym_db.RegisterMessage(SetPoliciesRequest)

AddDefinedSetRequest = _reflection.GeneratedProtocolMessageType('AddDefinedSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDDEFINEDSETREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddDefinedSetRequest)
  })
_sym_db.RegisterMessage(AddDefinedSetRequest)

DeleteDefinedSetRequest = _reflection.GeneratedProtocolMessageType('DeleteDefinedSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDEFINEDSETREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeleteDefinedSetRequest)
  })
_sym_db.RegisterMessage(DeleteDefinedSetRequest)

ListDefinedSetRequest = _reflection.GeneratedProtocolMessageType('ListDefinedSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEFINEDSETREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListDefinedSetRequest)
  })
_sym_db.RegisterMessage(ListDefinedSetRequest)

ListDefinedSetResponse = _reflection.GeneratedProtocolMessageType('ListDefinedSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEFINEDSETRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListDefinedSetResponse)
  })
_sym_db.RegisterMessage(ListDefinedSetResponse)

AddStatementRequest = _reflection.GeneratedProtocolMessageType('AddStatementRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSTATEMENTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddStatementRequest)
  })
_sym_db.RegisterMessage(AddStatementRequest)

DeleteStatementRequest = _reflection.GeneratedProtocolMessageType('DeleteStatementRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTATEMENTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeleteStatementRequest)
  })
_sym_db.RegisterMessage(DeleteStatementRequest)

ListStatementRequest = _reflection.GeneratedProtocolMessageType('ListStatementRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTATEMENTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListStatementRequest)
  })
_sym_db.RegisterMessage(ListStatementRequest)

ListStatementResponse = _reflection.GeneratedProtocolMessageType('ListStatementResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTATEMENTRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListStatementResponse)
  })
_sym_db.RegisterMessage(ListStatementResponse)

AddPolicyAssignmentRequest = _reflection.GeneratedProtocolMessageType('AddPolicyAssignmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPOLICYASSIGNMENTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPolicyAssignmentRequest)
  })
_sym_db.RegisterMessage(AddPolicyAssignmentRequest)

DeletePolicyAssignmentRequest = _reflection.GeneratedProtocolMessageType('DeletePolicyAssignmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOLICYASSIGNMENTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeletePolicyAssignmentRequest)
  })
_sym_db.RegisterMessage(DeletePolicyAssignmentRequest)

ListPolicyAssignmentRequest = _reflection.GeneratedProtocolMessageType('ListPolicyAssignmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOLICYASSIGNMENTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPolicyAssignmentRequest)
  })
_sym_db.RegisterMessage(ListPolicyAssignmentRequest)

ListPolicyAssignmentResponse = _reflection.GeneratedProtocolMessageType('ListPolicyAssignmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOLICYASSIGNMENTRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListPolicyAssignmentResponse)
  })
_sym_db.RegisterMessage(ListPolicyAssignmentResponse)

SetPolicyAssignmentRequest = _reflection.GeneratedProtocolMessageType('SetPolicyAssignmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPOLICYASSIGNMENTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SetPolicyAssignmentRequest)
  })
_sym_db.RegisterMessage(SetPolicyAssignmentRequest)

AddRpkiRequest = _reflection.GeneratedProtocolMessageType('AddRpkiRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDRPKIREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddRpkiRequest)
  })
_sym_db.RegisterMessage(AddRpkiRequest)

DeleteRpkiRequest = _reflection.GeneratedProtocolMessageType('DeleteRpkiRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERPKIREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeleteRpkiRequest)
  })
_sym_db.RegisterMessage(DeleteRpkiRequest)

ListRpkiRequest = _reflection.GeneratedProtocolMessageType('ListRpkiRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRPKIREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListRpkiRequest)
  })
_sym_db.RegisterMessage(ListRpkiRequest)

ListRpkiResponse = _reflection.GeneratedProtocolMessageType('ListRpkiResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRPKIRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListRpkiResponse)
  })
_sym_db.RegisterMessage(ListRpkiResponse)

EnableRpkiRequest = _reflection.GeneratedProtocolMessageType('EnableRpkiRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENABLERPKIREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EnableRpkiRequest)
  })
_sym_db.RegisterMessage(EnableRpkiRequest)

DisableRpkiRequest = _reflection.GeneratedProtocolMessageType('DisableRpkiRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLERPKIREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DisableRpkiRequest)
  })
_sym_db.RegisterMessage(DisableRpkiRequest)

ResetRpkiRequest = _reflection.GeneratedProtocolMessageType('ResetRpkiRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETRPKIREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ResetRpkiRequest)
  })
_sym_db.RegisterMessage(ResetRpkiRequest)

ListRpkiTableRequest = _reflection.GeneratedProtocolMessageType('ListRpkiTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRPKITABLEREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListRpkiTableRequest)
  })
_sym_db.RegisterMessage(ListRpkiTableRequest)

ListRpkiTableResponse = _reflection.GeneratedProtocolMessageType('ListRpkiTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRPKITABLERESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListRpkiTableResponse)
  })
_sym_db.RegisterMessage(ListRpkiTableResponse)

EnableZebraRequest = _reflection.GeneratedProtocolMessageType('EnableZebraRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEZEBRAREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EnableZebraRequest)
  })
_sym_db.RegisterMessage(EnableZebraRequest)

EnableMrtRequest = _reflection.GeneratedProtocolMessageType('EnableMrtRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENABLEMRTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EnableMrtRequest)
  })
_sym_db.RegisterMessage(EnableMrtRequest)

DisableMrtRequest = _reflection.GeneratedProtocolMessageType('DisableMrtRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISABLEMRTREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DisableMrtRequest)
  })
_sym_db.RegisterMessage(DisableMrtRequest)

AddBmpRequest = _reflection.GeneratedProtocolMessageType('AddBmpRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDBMPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddBmpRequest)
  })
_sym_db.RegisterMessage(AddBmpRequest)

DeleteBmpRequest = _reflection.GeneratedProtocolMessageType('DeleteBmpRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBMPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DeleteBmpRequest)
  })
_sym_db.RegisterMessage(DeleteBmpRequest)

ListBmpRequest = _reflection.GeneratedProtocolMessageType('ListBmpRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBMPREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListBmpRequest)
  })
_sym_db.RegisterMessage(ListBmpRequest)

ListBmpResponse = _reflection.GeneratedProtocolMessageType('ListBmpResponse', (_message.Message,), {

  'BmpStation' : _reflection.GeneratedProtocolMessageType('BmpStation', (_message.Message,), {

    'Conf' : _reflection.GeneratedProtocolMessageType('Conf', (_message.Message,), {
      'DESCRIPTOR' : _LISTBMPRESPONSE_BMPSTATION_CONF,
      '__module__' : 'gobgp_pb2'
      # @@protoc_insertion_point(class_scope:apipb.ListBmpResponse.BmpStation.Conf)
      })
    ,

    'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
      'DESCRIPTOR' : _LISTBMPRESPONSE_BMPSTATION_STATE,
      '__module__' : 'gobgp_pb2'
      # @@protoc_insertion_point(class_scope:apipb.ListBmpResponse.BmpStation.State)
      })
    ,
    'DESCRIPTOR' : _LISTBMPRESPONSE_BMPSTATION,
    '__module__' : 'gobgp_pb2'
    # @@protoc_insertion_point(class_scope:apipb.ListBmpResponse.BmpStation)
    })
  ,
  'DESCRIPTOR' : _LISTBMPRESPONSE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ListBmpResponse)
  })
_sym_db.RegisterMessage(ListBmpResponse)
_sym_db.RegisterMessage(ListBmpResponse.BmpStation)
_sym_db.RegisterMessage(ListBmpResponse.BmpStation.Conf)
_sym_db.RegisterMessage(ListBmpResponse.BmpStation.State)

Family = _reflection.GeneratedProtocolMessageType('Family', (_message.Message,), {
  'DESCRIPTOR' : _FAMILY,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Family)
  })
_sym_db.RegisterMessage(Family)

Validation = _reflection.GeneratedProtocolMessageType('Validation', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATION,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Validation)
  })
_sym_db.RegisterMessage(Validation)

Path = _reflection.GeneratedProtocolMessageType('Path', (_message.Message,), {
  'DESCRIPTOR' : _PATH,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Path)
  })
_sym_db.RegisterMessage(Path)

Destination = _reflection.GeneratedProtocolMessageType('Destination', (_message.Message,), {
  'DESCRIPTOR' : _DESTINATION,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Destination)
  })
_sym_db.RegisterMessage(Destination)

Peer = _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), {
  'DESCRIPTOR' : _PEER,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Peer)
  })
_sym_db.RegisterMessage(Peer)

PeerGroup = _reflection.GeneratedProtocolMessageType('PeerGroup', (_message.Message,), {
  'DESCRIPTOR' : _PEERGROUP,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PeerGroup)
  })
_sym_db.RegisterMessage(PeerGroup)

DynamicNeighbor = _reflection.GeneratedProtocolMessageType('DynamicNeighbor', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICNEIGHBOR,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DynamicNeighbor)
  })
_sym_db.RegisterMessage(DynamicNeighbor)

ApplyPolicy = _reflection.GeneratedProtocolMessageType('ApplyPolicy', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPOLICY,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.ApplyPolicy)
  })
_sym_db.RegisterMessage(ApplyPolicy)

PrefixLimit = _reflection.GeneratedProtocolMessageType('PrefixLimit', (_message.Message,), {
  'DESCRIPTOR' : _PREFIXLIMIT,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PrefixLimit)
  })
_sym_db.RegisterMessage(PrefixLimit)

PeerConf = _reflection.GeneratedProtocolMessageType('PeerConf', (_message.Message,), {
  'DESCRIPTOR' : _PEERCONF,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PeerConf)
  })
_sym_db.RegisterMessage(PeerConf)

PeerGroupConf = _reflection.GeneratedProtocolMessageType('PeerGroupConf', (_message.Message,), {
  'DESCRIPTOR' : _PEERGROUPCONF,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PeerGroupConf)
  })
_sym_db.RegisterMessage(PeerGroupConf)

PeerGroupState = _reflection.GeneratedProtocolMessageType('PeerGroupState', (_message.Message,), {
  'DESCRIPTOR' : _PEERGROUPSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PeerGroupState)
  })
_sym_db.RegisterMessage(PeerGroupState)

TtlSecurity = _reflection.GeneratedProtocolMessageType('TtlSecurity', (_message.Message,), {
  'DESCRIPTOR' : _TTLSECURITY,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TtlSecurity)
  })
_sym_db.RegisterMessage(TtlSecurity)

EbgpMultihop = _reflection.GeneratedProtocolMessageType('EbgpMultihop', (_message.Message,), {
  'DESCRIPTOR' : _EBGPMULTIHOP,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EbgpMultihop)
  })
_sym_db.RegisterMessage(EbgpMultihop)

RouteReflector = _reflection.GeneratedProtocolMessageType('RouteReflector', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEREFLECTOR,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteReflector)
  })
_sym_db.RegisterMessage(RouteReflector)

PeerState = _reflection.GeneratedProtocolMessageType('PeerState', (_message.Message,), {
  'DESCRIPTOR' : _PEERSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PeerState)
  })
_sym_db.RegisterMessage(PeerState)

Messages = _reflection.GeneratedProtocolMessageType('Messages', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGES,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Messages)
  })
_sym_db.RegisterMessage(Messages)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Message)
  })
_sym_db.RegisterMessage(Message)

Queues = _reflection.GeneratedProtocolMessageType('Queues', (_message.Message,), {
  'DESCRIPTOR' : _QUEUES,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Queues)
  })
_sym_db.RegisterMessage(Queues)

Timers = _reflection.GeneratedProtocolMessageType('Timers', (_message.Message,), {
  'DESCRIPTOR' : _TIMERS,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Timers)
  })
_sym_db.RegisterMessage(Timers)

TimersConfig = _reflection.GeneratedProtocolMessageType('TimersConfig', (_message.Message,), {
  'DESCRIPTOR' : _TIMERSCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TimersConfig)
  })
_sym_db.RegisterMessage(TimersConfig)

TimersState = _reflection.GeneratedProtocolMessageType('TimersState', (_message.Message,), {
  'DESCRIPTOR' : _TIMERSSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.TimersState)
  })
_sym_db.RegisterMessage(TimersState)

Transport = _reflection.GeneratedProtocolMessageType('Transport', (_message.Message,), {
  'DESCRIPTOR' : _TRANSPORT,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Transport)
  })
_sym_db.RegisterMessage(Transport)

RouteServer = _reflection.GeneratedProtocolMessageType('RouteServer', (_message.Message,), {
  'DESCRIPTOR' : _ROUTESERVER,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteServer)
  })
_sym_db.RegisterMessage(RouteServer)

GracefulRestart = _reflection.GeneratedProtocolMessageType('GracefulRestart', (_message.Message,), {
  'DESCRIPTOR' : _GRACEFULRESTART,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.GracefulRestart)
  })
_sym_db.RegisterMessage(GracefulRestart)

MpGracefulRestartConfig = _reflection.GeneratedProtocolMessageType('MpGracefulRestartConfig', (_message.Message,), {
  'DESCRIPTOR' : _MPGRACEFULRESTARTCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MpGracefulRestartConfig)
  })
_sym_db.RegisterMessage(MpGracefulRestartConfig)

MpGracefulRestartState = _reflection.GeneratedProtocolMessageType('MpGracefulRestartState', (_message.Message,), {
  'DESCRIPTOR' : _MPGRACEFULRESTARTSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MpGracefulRestartState)
  })
_sym_db.RegisterMessage(MpGracefulRestartState)

MpGracefulRestart = _reflection.GeneratedProtocolMessageType('MpGracefulRestart', (_message.Message,), {
  'DESCRIPTOR' : _MPGRACEFULRESTART,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MpGracefulRestart)
  })
_sym_db.RegisterMessage(MpGracefulRestart)

AfiSafiConfig = _reflection.GeneratedProtocolMessageType('AfiSafiConfig', (_message.Message,), {
  'DESCRIPTOR' : _AFISAFICONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AfiSafiConfig)
  })
_sym_db.RegisterMessage(AfiSafiConfig)

AfiSafiState = _reflection.GeneratedProtocolMessageType('AfiSafiState', (_message.Message,), {
  'DESCRIPTOR' : _AFISAFISTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AfiSafiState)
  })
_sym_db.RegisterMessage(AfiSafiState)

RouteSelectionOptionsConfig = _reflection.GeneratedProtocolMessageType('RouteSelectionOptionsConfig', (_message.Message,), {
  'DESCRIPTOR' : _ROUTESELECTIONOPTIONSCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteSelectionOptionsConfig)
  })
_sym_db.RegisterMessage(RouteSelectionOptionsConfig)

RouteSelectionOptionsState = _reflection.GeneratedProtocolMessageType('RouteSelectionOptionsState', (_message.Message,), {
  'DESCRIPTOR' : _ROUTESELECTIONOPTIONSSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteSelectionOptionsState)
  })
_sym_db.RegisterMessage(RouteSelectionOptionsState)

RouteSelectionOptions = _reflection.GeneratedProtocolMessageType('RouteSelectionOptions', (_message.Message,), {
  'DESCRIPTOR' : _ROUTESELECTIONOPTIONS,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteSelectionOptions)
  })
_sym_db.RegisterMessage(RouteSelectionOptions)

UseMultiplePathsConfig = _reflection.GeneratedProtocolMessageType('UseMultiplePathsConfig', (_message.Message,), {
  'DESCRIPTOR' : _USEMULTIPLEPATHSCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UseMultiplePathsConfig)
  })
_sym_db.RegisterMessage(UseMultiplePathsConfig)

UseMultiplePathsState = _reflection.GeneratedProtocolMessageType('UseMultiplePathsState', (_message.Message,), {
  'DESCRIPTOR' : _USEMULTIPLEPATHSSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UseMultiplePathsState)
  })
_sym_db.RegisterMessage(UseMultiplePathsState)

EbgpConfig = _reflection.GeneratedProtocolMessageType('EbgpConfig', (_message.Message,), {
  'DESCRIPTOR' : _EBGPCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EbgpConfig)
  })
_sym_db.RegisterMessage(EbgpConfig)

EbgpState = _reflection.GeneratedProtocolMessageType('EbgpState', (_message.Message,), {
  'DESCRIPTOR' : _EBGPSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.EbgpState)
  })
_sym_db.RegisterMessage(EbgpState)

Ebgp = _reflection.GeneratedProtocolMessageType('Ebgp', (_message.Message,), {
  'DESCRIPTOR' : _EBGP,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Ebgp)
  })
_sym_db.RegisterMessage(Ebgp)

IbgpConfig = _reflection.GeneratedProtocolMessageType('IbgpConfig', (_message.Message,), {
  'DESCRIPTOR' : _IBGPCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.IbgpConfig)
  })
_sym_db.RegisterMessage(IbgpConfig)

IbgpState = _reflection.GeneratedProtocolMessageType('IbgpState', (_message.Message,), {
  'DESCRIPTOR' : _IBGPSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.IbgpState)
  })
_sym_db.RegisterMessage(IbgpState)

Ibgp = _reflection.GeneratedProtocolMessageType('Ibgp', (_message.Message,), {
  'DESCRIPTOR' : _IBGP,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Ibgp)
  })
_sym_db.RegisterMessage(Ibgp)

UseMultiplePaths = _reflection.GeneratedProtocolMessageType('UseMultiplePaths', (_message.Message,), {
  'DESCRIPTOR' : _USEMULTIPLEPATHS,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.UseMultiplePaths)
  })
_sym_db.RegisterMessage(UseMultiplePaths)

RouteTargetMembershipConfig = _reflection.GeneratedProtocolMessageType('RouteTargetMembershipConfig', (_message.Message,), {
  'DESCRIPTOR' : _ROUTETARGETMEMBERSHIPCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteTargetMembershipConfig)
  })
_sym_db.RegisterMessage(RouteTargetMembershipConfig)

RouteTargetMembershipState = _reflection.GeneratedProtocolMessageType('RouteTargetMembershipState', (_message.Message,), {
  'DESCRIPTOR' : _ROUTETARGETMEMBERSHIPSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteTargetMembershipState)
  })
_sym_db.RegisterMessage(RouteTargetMembershipState)

RouteTargetMembership = _reflection.GeneratedProtocolMessageType('RouteTargetMembership', (_message.Message,), {
  'DESCRIPTOR' : _ROUTETARGETMEMBERSHIP,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RouteTargetMembership)
  })
_sym_db.RegisterMessage(RouteTargetMembership)

LongLivedGracefulRestartConfig = _reflection.GeneratedProtocolMessageType('LongLivedGracefulRestartConfig', (_message.Message,), {
  'DESCRIPTOR' : _LONGLIVEDGRACEFULRESTARTCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LongLivedGracefulRestartConfig)
  })
_sym_db.RegisterMessage(LongLivedGracefulRestartConfig)

LongLivedGracefulRestartState = _reflection.GeneratedProtocolMessageType('LongLivedGracefulRestartState', (_message.Message,), {
  'DESCRIPTOR' : _LONGLIVEDGRACEFULRESTARTSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LongLivedGracefulRestartState)
  })
_sym_db.RegisterMessage(LongLivedGracefulRestartState)

LongLivedGracefulRestart = _reflection.GeneratedProtocolMessageType('LongLivedGracefulRestart', (_message.Message,), {
  'DESCRIPTOR' : _LONGLIVEDGRACEFULRESTART,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LongLivedGracefulRestart)
  })
_sym_db.RegisterMessage(LongLivedGracefulRestart)

AfiSafi = _reflection.GeneratedProtocolMessageType('AfiSafi', (_message.Message,), {
  'DESCRIPTOR' : _AFISAFI,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AfiSafi)
  })
_sym_db.RegisterMessage(AfiSafi)

AddPathsConfig = _reflection.GeneratedProtocolMessageType('AddPathsConfig', (_message.Message,), {
  'DESCRIPTOR' : _ADDPATHSCONFIG,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPathsConfig)
  })
_sym_db.RegisterMessage(AddPathsConfig)

AddPathsState = _reflection.GeneratedProtocolMessageType('AddPathsState', (_message.Message,), {
  'DESCRIPTOR' : _ADDPATHSSTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPathsState)
  })
_sym_db.RegisterMessage(AddPathsState)

AddPaths = _reflection.GeneratedProtocolMessageType('AddPaths', (_message.Message,), {
  'DESCRIPTOR' : _ADDPATHS,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AddPaths)
  })
_sym_db.RegisterMessage(AddPaths)

Prefix = _reflection.GeneratedProtocolMessageType('Prefix', (_message.Message,), {
  'DESCRIPTOR' : _PREFIX,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Prefix)
  })
_sym_db.RegisterMessage(Prefix)

DefinedSet = _reflection.GeneratedProtocolMessageType('DefinedSet', (_message.Message,), {
  'DESCRIPTOR' : _DEFINEDSET,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DefinedSet)
  })
_sym_db.RegisterMessage(DefinedSet)

MatchSet = _reflection.GeneratedProtocolMessageType('MatchSet', (_message.Message,), {
  'DESCRIPTOR' : _MATCHSET,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MatchSet)
  })
_sym_db.RegisterMessage(MatchSet)

AsPathLength = _reflection.GeneratedProtocolMessageType('AsPathLength', (_message.Message,), {
  'DESCRIPTOR' : _ASPATHLENGTH,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AsPathLength)
  })
_sym_db.RegisterMessage(AsPathLength)

Conditions = _reflection.GeneratedProtocolMessageType('Conditions', (_message.Message,), {
  'DESCRIPTOR' : _CONDITIONS,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Conditions)
  })
_sym_db.RegisterMessage(Conditions)

CommunityAction = _reflection.GeneratedProtocolMessageType('CommunityAction', (_message.Message,), {
  'DESCRIPTOR' : _COMMUNITYACTION,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.CommunityAction)
  })
_sym_db.RegisterMessage(CommunityAction)

MedAction = _reflection.GeneratedProtocolMessageType('MedAction', (_message.Message,), {
  'DESCRIPTOR' : _MEDACTION,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.MedAction)
  })
_sym_db.RegisterMessage(MedAction)

AsPrependAction = _reflection.GeneratedProtocolMessageType('AsPrependAction', (_message.Message,), {
  'DESCRIPTOR' : _ASPREPENDACTION,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.AsPrependAction)
  })
_sym_db.RegisterMessage(AsPrependAction)

NexthopAction = _reflection.GeneratedProtocolMessageType('NexthopAction', (_message.Message,), {
  'DESCRIPTOR' : _NEXTHOPACTION,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.NexthopAction)
  })
_sym_db.RegisterMessage(NexthopAction)

LocalPrefAction = _reflection.GeneratedProtocolMessageType('LocalPrefAction', (_message.Message,), {
  'DESCRIPTOR' : _LOCALPREFACTION,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.LocalPrefAction)
  })
_sym_db.RegisterMessage(LocalPrefAction)

Actions = _reflection.GeneratedProtocolMessageType('Actions', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONS,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Actions)
  })
_sym_db.RegisterMessage(Actions)

Statement = _reflection.GeneratedProtocolMessageType('Statement', (_message.Message,), {
  'DESCRIPTOR' : _STATEMENT,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Statement)
  })
_sym_db.RegisterMessage(Statement)

Policy = _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), {
  'DESCRIPTOR' : _POLICY,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Policy)
  })
_sym_db.RegisterMessage(Policy)

PolicyAssignment = _reflection.GeneratedProtocolMessageType('PolicyAssignment', (_message.Message,), {
  'DESCRIPTOR' : _POLICYASSIGNMENT,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.PolicyAssignment)
  })
_sym_db.RegisterMessage(PolicyAssignment)

RoutingPolicy = _reflection.GeneratedProtocolMessageType('RoutingPolicy', (_message.Message,), {
  'DESCRIPTOR' : _ROUTINGPOLICY,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RoutingPolicy)
  })
_sym_db.RegisterMessage(RoutingPolicy)

Roa = _reflection.GeneratedProtocolMessageType('Roa', (_message.Message,), {
  'DESCRIPTOR' : _ROA,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Roa)
  })
_sym_db.RegisterMessage(Roa)

Vrf = _reflection.GeneratedProtocolMessageType('Vrf', (_message.Message,), {
  'DESCRIPTOR' : _VRF,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Vrf)
  })
_sym_db.RegisterMessage(Vrf)

DefaultRouteDistance = _reflection.GeneratedProtocolMessageType('DefaultRouteDistance', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTROUTEDISTANCE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.DefaultRouteDistance)
  })
_sym_db.RegisterMessage(DefaultRouteDistance)

Global = _reflection.GeneratedProtocolMessageType('Global', (_message.Message,), {
  'DESCRIPTOR' : _GLOBAL,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Global)
  })
_sym_db.RegisterMessage(Global)

Confederation = _reflection.GeneratedProtocolMessageType('Confederation', (_message.Message,), {
  'DESCRIPTOR' : _CONFEDERATION,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Confederation)
  })
_sym_db.RegisterMessage(Confederation)

RPKIConf = _reflection.GeneratedProtocolMessageType('RPKIConf', (_message.Message,), {
  'DESCRIPTOR' : _RPKICONF,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RPKIConf)
  })
_sym_db.RegisterMessage(RPKIConf)

RPKIState = _reflection.GeneratedProtocolMessageType('RPKIState', (_message.Message,), {
  'DESCRIPTOR' : _RPKISTATE,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.RPKIState)
  })
_sym_db.RegisterMessage(RPKIState)

Rpki = _reflection.GeneratedProtocolMessageType('Rpki', (_message.Message,), {
  'DESCRIPTOR' : _RPKI,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.Rpki)
  })
_sym_db.RegisterMessage(Rpki)

SetLogLevelRequest = _reflection.GeneratedProtocolMessageType('SetLogLevelRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLOGLEVELREQUEST,
  '__module__' : 'gobgp_pb2'
  # @@protoc_insertion_point(class_scope:apipb.SetLogLevelRequest)
  })
_sym_db.RegisterMessage(SetLogLevelRequest)

_GOBGPAPI = DESCRIPTOR.services_by_name['GobgpApi']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/osrg/gobgp/v3/api;apipb'
  _TABLETYPE._serialized_start=18941
  _TABLETYPE._serialized_end=19009
  _PEERTYPE._serialized_start=19011
  _PEERTYPE._serialized_end=19049
  _REMOVEPRIVATE._serialized_start=19051
  _REMOVEPRIVATE._serialized_end=19112
  _DEFINEDTYPE._serialized_start=19115
  _DEFINEDTYPE._serialized_end=19245
  _ROUTEACTION._serialized_start=19247
  _ROUTEACTION._serialized_end=19294
  _POLICYDIRECTION._serialized_start=19296
  _POLICYDIRECTION._serialized_end=19350
  _STARTBGPREQUEST._serialized_start=111
  _STARTBGPREQUEST._serialized_end=159
  _STOPBGPREQUEST._serialized_start=161
  _STOPBGPREQUEST._serialized_end=177
  _GETBGPREQUEST._serialized_start=179
  _GETBGPREQUEST._serialized_end=194
  _GETBGPRESPONSE._serialized_start=196
  _GETBGPRESPONSE._serialized_end=243
  _WATCHEVENTREQUEST._serialized_start=246
  _WATCHEVENTREQUEST._serialized_end=602
  _WATCHEVENTREQUEST_PEER._serialized_start=359
  _WATCHEVENTREQUEST_PEER._serialized_end=365
  _WATCHEVENTREQUEST_TABLE._serialized_start=368
  _WATCHEVENTREQUEST_TABLE._serialized_end=602
  _WATCHEVENTREQUEST_TABLE_FILTER._serialized_start=434
  _WATCHEVENTREQUEST_TABLE_FILTER._serialized_end=602
  _WATCHEVENTREQUEST_TABLE_FILTER_TYPE._serialized_start=558
  _WATCHEVENTREQUEST_TABLE_FILTER_TYPE._serialized_end=602
  _WATCHEVENTRESPONSE._serialized_start=605
  _WATCHEVENTRESPONSE._serialized_end=940
  _WATCHEVENTRESPONSE_PEEREVENT._serialized_start=736
  _WATCHEVENTRESPONSE_PEEREVENT._serialized_end=889
  _WATCHEVENTRESPONSE_PEEREVENT_TYPE._serialized_start=832
  _WATCHEVENTRESPONSE_PEEREVENT_TYPE._serialized_end=889
  _WATCHEVENTRESPONSE_TABLEEVENT._serialized_start=891
  _WATCHEVENTRESPONSE_TABLEEVENT._serialized_end=931
  _ADDPEERREQUEST._serialized_start=942
  _ADDPEERREQUEST._serialized_end=985
  _DELETEPEERREQUEST._serialized_start=987
  _DELETEPEERREQUEST._serialized_end=1042
  _LISTPEERREQUEST._serialized_start=1044
  _LISTPEERREQUEST._serialized_end=1104
  _LISTPEERRESPONSE._serialized_start=1106
  _LISTPEERRESPONSE._serialized_end=1151
  _UPDATEPEERREQUEST._serialized_start=1153
  _UPDATEPEERREQUEST._serialized_end=1225
  _UPDATEPEERRESPONSE._serialized_start=1227
  _UPDATEPEERRESPONSE._serialized_end=1276
  _RESETPEERREQUEST._serialized_start=1279
  _RESETPEERREQUEST._serialized_end=1463
  _RESETPEERREQUEST_SOFTRESETDIRECTION._serialized_start=1416
  _RESETPEERREQUEST_SOFTRESETDIRECTION._serialized_end=1463
  _SHUTDOWNPEERREQUEST._serialized_start=1465
  _SHUTDOWNPEERREQUEST._serialized_end=1526
  _ENABLEPEERREQUEST._serialized_start=1528
  _ENABLEPEERREQUEST._serialized_end=1564
  _DISABLEPEERREQUEST._serialized_start=1566
  _DISABLEPEERREQUEST._serialized_end=1626
  _ADDPEERGROUPREQUEST._serialized_start=1628
  _ADDPEERGROUPREQUEST._serialized_end=1687
  _DELETEPEERGROUPREQUEST._serialized_start=1689
  _DELETEPEERGROUPREQUEST._serialized_end=1727
  _UPDATEPEERGROUPREQUEST._serialized_start=1729
  _UPDATEPEERGROUPREQUEST._serialized_end=1817
  _UPDATEPEERGROUPRESPONSE._serialized_start=1819
  _UPDATEPEERGROUPRESPONSE._serialized_end=1873
  _LISTPEERGROUPREQUEST._serialized_start=1875
  _LISTPEERGROUPREQUEST._serialized_end=1922
  _LISTPEERGROUPRESPONSE._serialized_start=1924
  _LISTPEERGROUPRESPONSE._serialized_end=1985
  _ADDDYNAMICNEIGHBORREQUEST._serialized_start=1987
  _ADDDYNAMICNEIGHBORREQUEST._serialized_end=2064
  _DELETEDYNAMICNEIGHBORREQUEST._serialized_start=2066
  _DELETEDYNAMICNEIGHBORREQUEST._serialized_end=2132
  _LISTDYNAMICNEIGHBORREQUEST._serialized_start=2134
  _LISTDYNAMICNEIGHBORREQUEST._serialized_end=2182
  _LISTDYNAMICNEIGHBORRESPONSE._serialized_start=2184
  _LISTDYNAMICNEIGHBORRESPONSE._serialized_end=2263
  _ADDPATHREQUEST._serialized_start=2265
  _ADDPATHREQUEST._serialized_end=2362
  _ADDPATHRESPONSE._serialized_start=2364
  _ADDPATHRESPONSE._serialized_end=2395
  _DELETEPATHREQUEST._serialized_start=2398
  _DELETEPATHREQUEST._serialized_end=2543
  _TABLELOOKUPPREFIX._serialized_start=2546
  _TABLELOOKUPPREFIX._serialized_end=2682
  _TABLELOOKUPPREFIX_TYPE._serialized_start=2640
  _TABLELOOKUPPREFIX_TYPE._serialized_end=2682
  _LISTPATHREQUEST._serialized_start=2685
  _LISTPATHREQUEST._serialized_end=3049
  _LISTPATHREQUEST_SORTTYPE._serialized_start=3017
  _LISTPATHREQUEST_SORTTYPE._serialized_end=3049
  _LISTPATHRESPONSE._serialized_start=3051
  _LISTPATHRESPONSE._serialized_end=3110
  _ADDPATHSTREAMREQUEST._serialized_start=3112
  _ADDPATHSTREAMREQUEST._serialized_end=3216
  _GETTABLEREQUEST._serialized_start=3218
  _GETTABLEREQUEST._serialized_end=3318
  _GETTABLERESPONSE._serialized_start=3320
  _GETTABLERESPONSE._serialized_end=3403
  _ADDVRFREQUEST._serialized_start=3405
  _ADDVRFREQUEST._serialized_end=3445
  _DELETEVRFREQUEST._serialized_start=3447
  _DELETEVRFREQUEST._serialized_end=3479
  _LISTVRFREQUEST._serialized_start=3481
  _LISTVRFREQUEST._serialized_end=3511
  _LISTVRFRESPONSE._serialized_start=3513
  _LISTVRFRESPONSE._serialized_end=3555
  _ADDPOLICYREQUEST._serialized_start=3557
  _ADDPOLICYREQUEST._serialized_end=3641
  _DELETEPOLICYREQUEST._serialized_start=3643
  _DELETEPOLICYREQUEST._serialized_end=3737
  _LISTPOLICYREQUEST._serialized_start=3739
  _LISTPOLICYREQUEST._serialized_end=3772
  _LISTPOLICYRESPONSE._serialized_start=3774
  _LISTPOLICYRESPONSE._serialized_end=3825
  _SETPOLICIESREQUEST._serialized_start=3828
  _SETPOLICIESREQUEST._serialized_end=3968
  _ADDDEFINEDSETREQUEST._serialized_start=3970
  _ADDDEFINEDSETREQUEST._serialized_end=4032
  _DELETEDEFINEDSETREQUEST._serialized_start=4034
  _DELETEDEFINEDSETREQUEST._serialized_end=4112
  _LISTDEFINEDSETREQUEST._serialized_start=4114
  _LISTDEFINEDSETREQUEST._serialized_end=4193
  _LISTDEFINEDSETRESPONSE._serialized_start=4195
  _LISTDEFINEDSETRESPONSE._serialized_end=4259
  _ADDSTATEMENTREQUEST._serialized_start=4261
  _ADDSTATEMENTREQUEST._serialized_end=4319
  _DELETESTATEMENTREQUEST._serialized_start=4321
  _DELETESTATEMENTREQUEST._serialized_end=4395
  _LISTSTATEMENTREQUEST._serialized_start=4397
  _LISTSTATEMENTREQUEST._serialized_end=4433
  _LISTSTATEMENTRESPONSE._serialized_start=4435
  _LISTSTATEMENTRESPONSE._serialized_end=4495
  _ADDPOLICYASSIGNMENTREQUEST._serialized_start=4497
  _ADDPOLICYASSIGNMENTREQUEST._serialized_end=4570
  _DELETEPOLICYASSIGNMENTREQUEST._serialized_start=4572
  _DELETEPOLICYASSIGNMENTREQUEST._serialized_end=4661
  _LISTPOLICYASSIGNMENTREQUEST._serialized_start=4663
  _LISTPOLICYASSIGNMENTREQUEST._serialized_end=4749
  _LISTPOLICYASSIGNMENTRESPONSE._serialized_start=4751
  _LISTPOLICYASSIGNMENTRESPONSE._serialized_end=4826
  _SETPOLICYASSIGNMENTREQUEST._serialized_start=4828
  _SETPOLICYASSIGNMENTREQUEST._serialized_end=4901
  _ADDRPKIREQUEST._serialized_start=4903
  _ADDRPKIREQUEST._serialized_end=4968
  _DELETERPKIREQUEST._serialized_start=4970
  _DELETERPKIREQUEST._serialized_end=5020
  _LISTRPKIREQUEST._serialized_start=5022
  _LISTRPKIREQUEST._serialized_end=5070
  _LISTRPKIRESPONSE._serialized_start=5072
  _LISTRPKIRESPONSE._serialized_end=5119
  _ENABLERPKIREQUEST._serialized_start=5121
  _ENABLERPKIREQUEST._serialized_end=5171
  _DISABLERPKIREQUEST._serialized_start=5173
  _DISABLERPKIREQUEST._serialized_end=5224
  _RESETRPKIREQUEST._serialized_start=5226
  _RESETRPKIREQUEST._serialized_end=5289
  _LISTRPKITABLEREQUEST._serialized_start=5291
  _LISTRPKITABLEREQUEST._serialized_end=5344
  _LISTRPKITABLERESPONSE._serialized_start=5346
  _LISTRPKITABLERESPONSE._serialized_end=5394
  _ENABLEZEBRAREQUEST._serialized_start=5397
  _ENABLEZEBRAREQUEST._serialized_end=5585
  _ENABLEMRTREQUEST._serialized_start=5588
  _ENABLEMRTREQUEST._serialized_end=5758
  _ENABLEMRTREQUEST_DUMPTYPE._serialized_start=5724
  _ENABLEMRTREQUEST_DUMPTYPE._serialized_end=5758
  _DISABLEMRTREQUEST._serialized_start=5760
  _DISABLEMRTREQUEST._serialized_end=5797
  _ADDBMPREQUEST._serialized_start=5800
  _ADDBMPREQUEST._serialized_end=6032
  _ADDBMPREQUEST_MONITORINGPOLICY._serialized_start=5965
  _ADDBMPREQUEST_MONITORINGPOLICY._serialized_end=6032
  _DELETEBMPREQUEST._serialized_start=6034
  _DELETEBMPREQUEST._serialized_end=6083
  _LISTBMPREQUEST._serialized_start=6085
  _LISTBMPREQUEST._serialized_end=6101
  _LISTBMPRESPONSE._serialized_start=6104
  _LISTBMPRESPONSE._serialized_end=6436
  _LISTBMPRESPONSE_BMPSTATION._serialized_start=6176
  _LISTBMPRESPONSE_BMPSTATION._serialized_end=6436
  _LISTBMPRESPONSE_BMPSTATION_CONF._serialized_start=6300
  _LISTBMPRESPONSE_BMPSTATION_CONF._serialized_end=6337
  _LISTBMPRESPONSE_BMPSTATION_STATE._serialized_start=6339
  _LISTBMPRESPONSE_BMPSTATION_STATE._serialized_end=6436
  _FAMILY._serialized_start=6439
  _FAMILY._serialized_end=6957
  _FAMILY_AFI._serialized_start=6515
  _FAMILY_AFI._serialized_end=6609
  _FAMILY_SAFI._serialized_start=6612
  _FAMILY_SAFI._serialized_end=6957
  _VALIDATION._serialized_start=6960
  _VALIDATION._serialized_end=7300
  _VALIDATION_STATE._serialized_start=7158
  _VALIDATION_STATE._serialized_end=7238
  _VALIDATION_REASON._serialized_start=7240
  _VALIDATION_REASON._serialized_end=7300
  _PATH._serialized_start=7303
  _PATH._serialized_end=7810
  _DESTINATION._serialized_start=7812
  _DESTINATION._serialized_end=7869
  _PEER._serialized_start=7872
  _PEER._serialized_end=8313
  _PEERGROUP._serialized_start=8316
  _PEERGROUP._serialized_end=8771
  _DYNAMICNEIGHBOR._serialized_start=8773
  _DYNAMICNEIGHBOR._serialized_end=8826
  _APPLYPOLICY._serialized_start=8829
  _APPLYPOLICY._serialized_end=8982
  _PREFIXLIMIT._serialized_start=8984
  _PREFIXLIMIT._serialized_end=9082
  _PEERCONF._serialized_start=9085
  _PEERCONF._serialized_end=9492
  _PEERGROUPCONF._serialized_start=9495
  _PEERGROUPCONF._serialized_end=9745
  _PEERGROUPSTATE._serialized_start=9748
  _PEERGROUPSTATE._serialized_end=10044
  _TTLSECURITY._serialized_start=10046
  _TTLSECURITY._serialized_end=10093
  _EBGPMULTIHOP._serialized_start=10095
  _EBGPMULTIHOP._serialized_end=10148
  _ROUTEREFLECTOR._serialized_start=10150
  _ROUTEREFLECTOR._serialized_end=10234
  _PEERSTATE._serialized_start=10237
  _PEERSTATE._serialized_end=10962
  _PEERSTATE_SESSIONSTATE._serialized_start=10808
  _PEERSTATE_SESSIONSTATE._serialized_end=10918
  _PEERSTATE_ADMINSTATE._serialized_start=10920
  _PEERSTATE_ADMINSTATE._serialized_end=10962
  _MESSAGES._serialized_start=10964
  _MESSAGES._serialized_end=11038
  _MESSAGE._serialized_start=11041
  _MESSAGE._serialized_end=11222
  _QUEUES._serialized_start=11224
  _QUEUES._serialized_end=11263
  _TIMERS._serialized_start=11265
  _TIMERS._serialized_end=11345
  _TIMERSCONFIG._serialized_start=11348
  _TIMERSCONFIG._serialized_end=11508
  _TIMERSSTATE._serialized_start=11511
  _TIMERSSTATE._serialized_end=11754
  _TRANSPORT._serialized_start=11757
  _TRANSPORT._serialized_end=11942
  _ROUTESERVER._serialized_start=11944
  _ROUTESERVER._serialized_end=12011
  _GRACEFULRESTART._serialized_start=12014
  _GRACEFULRESTART._serialized_end=12290
  _MPGRACEFULRESTARTCONFIG._serialized_start=12292
  _MPGRACEFULRESTARTCONFIG._serialized_end=12334
  _MPGRACEFULRESTARTSTATE._serialized_start=12337
  _MPGRACEFULRESTARTSTATE._serialized_end=12470
  _MPGRACEFULRESTART._serialized_start=12472
  _MPGRACEFULRESTART._serialized_end=12585
  _AFISAFICONFIG._serialized_start=12587
  _AFISAFICONFIG._serialized_end=12650
  _AFISAFISTATE._serialized_start=12652
  _AFISAFISTATE._serialized_end=12770
  _ROUTESELECTIONOPTIONSCONFIG._serialized_start=12773
  _ROUTESELECTIONOPTIONSCONFIG._serialized_end=13026
  _ROUTESELECTIONOPTIONSSTATE._serialized_start=13029
  _ROUTESELECTIONOPTIONSSTATE._serialized_end=13281
  _ROUTESELECTIONOPTIONS._serialized_start=13283
  _ROUTESELECTIONOPTIONS._serialized_end=13408
  _USEMULTIPLEPATHSCONFIG._serialized_start=13410
  _USEMULTIPLEPATHSCONFIG._serialized_end=13451
  _USEMULTIPLEPATHSSTATE._serialized_start=13453
  _USEMULTIPLEPATHSSTATE._serialized_end=13493
  _EBGPCONFIG._serialized_start=13495
  _EBGPCONFIG._serialized_end=13558
  _EBGPSTATE._serialized_start=13560
  _EBGPSTATE._serialized_end=13622
  _EBGP._serialized_start=13624
  _EBGP._serialized_end=13698
  _IBGPCONFIG._serialized_start=13700
  _IBGPCONFIG._serialized_end=13735
  _IBGPSTATE._serialized_start=13737
  _IBGPSTATE._serialized_end=13771
  _IBGP._serialized_start=13773
  _IBGP._serialized_end=13847
  _USEMULTIPLEPATHS._serialized_start=13850
  _USEMULTIPLEPATHS._serialized_end=14014
  _ROUTETARGETMEMBERSHIPCONFIG._serialized_start=14016
  _ROUTETARGETMEMBERSHIPCONFIG._serialized_end=14068
  _ROUTETARGETMEMBERSHIPSTATE._serialized_start=14070
  _ROUTETARGETMEMBERSHIPSTATE._serialized_end=14121
  _ROUTETARGETMEMBERSHIP._serialized_start=14123
  _ROUTETARGETMEMBERSHIP._serialized_end=14248
  _LONGLIVEDGRACEFULRESTARTCONFIG._serialized_start=14250
  _LONGLIVEDGRACEFULRESTARTCONFIG._serialized_end=14321
  _LONGLIVEDGRACEFULRESTARTSTATE._serialized_start=14324
  _LONGLIVEDGRACEFULRESTARTSTATE._serialized_end=14473
  _LONGLIVEDGRACEFULRESTART._serialized_start=14476
  _LONGLIVEDGRACEFULRESTART._serialized_end=14610
  _AFISAFI._serialized_start=14613
  _AFISAFI._serialized_end=15121
  _ADDPATHSCONFIG._serialized_start=15123
  _ADDPATHSCONFIG._serialized_end=15174
  _ADDPATHSSTATE._serialized_start=15176
  _ADDPATHSSTATE._serialized_end=15226
  _ADDPATHS._serialized_start=15228
  _ADDPATHS._serialized_end=15314
  _PREFIX._serialized_start=15316
  _PREFIX._serialized_end=15393
  _DEFINEDSET._serialized_start=15395
  _DEFINEDSET._serialized_end=15510
  _MATCHSET._serialized_start=15512
  _MATCHSET._serialized_end=15610
  _MATCHSET_TYPE._serialized_start=15574
  _MATCHSET_TYPE._serialized_end=15610
  _ASPATHLENGTH._serialized_start=15612
  _ASPATHLENGTH._serialized_end=15714
  _ASPATHLENGTH_TYPE._serialized_start=15684
  _ASPATHLENGTH_TYPE._serialized_end=15714
  _CONDITIONS._serialized_start=15717
  _CONDITIONS._serialized_end=16256
  _CONDITIONS_ROUTETYPE._serialized_start=16152
  _CONDITIONS_ROUTETYPE._serialized_end=16256
  _COMMUNITYACTION._serialized_start=16258
  _COMMUNITYACTION._serialized_end=16381
  _COMMUNITYACTION_TYPE._serialized_start=16341
  _COMMUNITYACTION_TYPE._serialized_end=16381
  _MEDACTION._serialized_start=16383
  _MEDACTION._serialized_end=16476
  _MEDACTION_TYPE._serialized_start=16448
  _MEDACTION_TYPE._serialized_end=16476
  _ASPREPENDACTION._serialized_start=16478
  _ASPREPENDACTION._serialized_end=16547
  _NEXTHOPACTION._serialized_start=16549
  _NEXTHOPACTION._serialized_end=16614
  _LOCALPREFACTION._serialized_start=16616
  _LOCALPREFACTION._serialized_end=16648
  _ACTIONS._serialized_start=16651
  _ACTIONS._serialized_end=16999
  _STATEMENT._serialized_start=17001
  _STATEMENT._serialized_end=17098
  _POLICY._serialized_start=17100
  _POLICY._serialized_end=17160
  _POLICYASSIGNMENT._serialized_start=17163
  _POLICYASSIGNMENT._serialized_end=17315
  _ROUTINGPOLICY._serialized_start=17317
  _ROUTINGPOLICY._serialized_end=17406
  _ROA._serialized_start=17408
  _ROA._serialized_end=17508
  _VRF._serialized_start=17511
  _VRF._serialized_end=17658
  _DEFAULTROUTEDISTANCE._serialized_start=17660
  _DEFAULTROUTEDISTANCE._serialized_end=17748
  _GLOBAL._serialized_start=17751
  _GLOBAL._serialized_end=18175
  _CONFEDERATION._serialized_start=18177
  _CONFEDERATION._serialized_end=18253
  _RPKICONF._serialized_start=18255
  _RPKICONF._serialized_end=18303
  _RPKISTATE._serialized_start=18306
  _RPKISTATE._serialized_end=18712
  _RPKI._serialized_start=18714
  _RPKI._serialized_end=18784
  _SETLOGLEVELREQUEST._serialized_start=18787
  _SETLOGLEVELREQUEST._serialized_end=18939
  _SETLOGLEVELREQUEST_LEVEL._serialized_start=18857
  _SETLOGLEVELREQUEST_LEVEL._serialized_end=18939
  _GOBGPAPI._serialized_start=19353
  _GOBGPAPI._serialized_end=23131
# @@protoc_insertion_point(module_scope)
